(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    349758,       6111]
NotebookOptionsPosition[    346795,       6052]
NotebookOutlinePosition[    347202,       6068]
CellTagsIndexPosition[    347159,       6065]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Geodesics", "Title",
 CellChangeTimes->{{3.861422752162422*^9, 
  3.8614227567645197`*^9}},ExpressionUUID->"c7713ff5-e9bb-4841-bfb3-\
71a9575d1fb4"],

Cell["Marvin Zanke & Leon von Detten", "Author",
 CellChangeTimes->{{3.8614227990481043`*^9, 
  3.861422810375845*^9}},ExpressionUUID->"2724983a-4dd7-4b30-8959-\
193de7f6cacf"],

Cell["13.05.2022", "Date",
 CellChangeTimes->{{3.861422812107274*^9, 3.861422818126668*^9}, 
   3.8616981729559317`*^9},ExpressionUUID->"64e24950-607f-4fc5-951a-\
860858ef15e1"],

Cell[TextData[{
 "In this notebook, we try to visualize the geodesic between two points on \
the surface of a cylinder. While it is more a less clear that the geodesic \
between two points in standard Euclidean space is just a straight line, this \
is not as trivial \[LongDash] although still easy in some sense \[LongDash] \
for the surface of a cylinder. We use cylindrical coordinates in the \
following, i.e., \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {"x"},
      {"y"},
      {"z"}
     }], ")"}], TraditionalForm]],ExpressionUUID->
  "95d010c2-c993-4221-95cb-c1560e9f7b5f"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {
       RowBox[{"r", " ", 
        RowBox[{"Cos", "(", "\[Phi]", ")"}]}]},
      {
       RowBox[{"r", " ", 
        RowBox[{"Sin", "(", "\[Phi]", ")"}]}]},
      {"z"}
     }], ")"}], TraditionalForm]],ExpressionUUID->
  "05947561-c91f-44e8-ad6f-c139e3beb85f"],
 ",\n\nwhere, for simplicity, we will use a cylinder of radius unity, i.e., \
r=1.\nIn the solution of the exercise, we found that the geodesic can be \
parameterized generically by the helix z(\[Phi]) = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], "\[Phi]"}], "+", 
    SubscriptBox["c", "2"]}], TraditionalForm]],ExpressionUUID->
  "d96b3d01-1ef1-4713-ba4a-462ca25e2114"],
 " on the surface of the cylinder. For the points on the cylinder that we \
want to connect with the geodesic, we will choose ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["p", "1"], "=", 
    RowBox[{"(", 
     RowBox[{"\[Phi]", "="}]}]}], TraditionalForm]],ExpressionUUID->
  "fad6e921-dcc6-4b9b-99d7-2f14aa536c15"],
 "0,z=0.5), ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["p", "2"], "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Phi]", "=", 
        FractionBox["\[Pi]", "2"]}], ",", 
       RowBox[{"z", "=", "1.5"}]}], ")"}]}], ","}], TraditionalForm]],
  ExpressionUUID->"c5d5bec4-0005-498c-a7ee-41b70d0e216f"],
 " so that the specific helix is fixed by the conditions z(0)=0.5 and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"z", "(", 
      FractionBox["\[Pi]", "2"], ")"}], "=", "1.5"}], ","}], 
   TraditionalForm]],ExpressionUUID->"0384ee0b-e14e-43e3-90f4-19b099f53ea4"],
 " leading to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "2"], "=", "0.5"}], TraditionalForm]],ExpressionUUID->
  "69b29c42-bb6d-49e9-aa72-474337722a50"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1.5", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["c", "1"], "*", 
        FractionBox["\[Pi]", "2"]}], "+", "0.5"}], "\[Rule]", 
      SubscriptBox["c", "1"]}], "=", 
     RowBox[{
      FractionBox["2", "\[Pi]"], "."}]}]}], TraditionalForm]],ExpressionUUID->
  "e1705dd9-2341-48f6-8f3a-2f7cd140d38c"],
 " \n",
 StyleBox["Note",
  FontVariations->{"Underline"->True}],
 ": it is important to have ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Phi]", "1"], "\[NotEqual]", 
    SubscriptBox["\[Phi]", "2"]}], TraditionalForm]],ExpressionUUID->
  "6f22ca22-d58e-4cb8-992b-77c95526aa12"],
 " and, for \[Phi] \[Element] [0,2\[Pi]), ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Phi]", "2"], "\[Element]", 
    RowBox[{"[", 
     RowBox[{"0", ",", "\[Pi]"}], "]"}]}], TraditionalForm]],ExpressionUUID->
  "a3811b57-e6d2-45f0-b9a0-64703b1335e4"],
 " if ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Phi]", "1"], "\[Element]", 
    RowBox[{"[", 
     RowBox[{"0", ",", "\[Pi]"}], "]"}]}], TraditionalForm]],ExpressionUUID->
  "cbccb895-5c74-4f90-8f89-b49b87ac3d61"],
 ", for otherwise the helix would sort of take the longer way (running in \
[mathematically] positive \[Phi]-direction) and not correspond to the \
geodesic. For ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Phi]", "1"], "\[Element]", 
     RowBox[{"[", 
      RowBox[{"\[Pi]", ",", 
       RowBox[{"2", "\[Pi]"}]}]}]}], ")"}], TraditionalForm]],ExpressionUUID->
  "d7c2e96c-2d0d-4f06-ad90-f555fa012ed0"],
 ", on the other hand, we need ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Phi]", "2"], "\[Element]", 
     RowBox[{"[", 
      RowBox[{"\[Pi]", ",", 
       RowBox[{"2", "\[Pi]"}]}]}]}], ")"}], TraditionalForm]],ExpressionUUID->
  "6f4d2da2-2ce5-4573-9668-c36b43a8528b"],
 ". This feature can, for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Phi]", "1"], "\[NotEqual]", 
    SubscriptBox["\[Phi]", "2"]}], TraditionalForm]],ExpressionUUID->
  "994b37ec-62f4-4b8f-9c34-5c9e5e4b7f19"],
 ", always be achieved by rotating the coordinate system accordingly. If the \
angle was chosen in the interval \[Phi] \[Element] (-\[Pi],\[Pi]], similar \
restrictions would have to be incorporated."
}], "Text",
 CellChangeTimes->{{3.86142281985277*^9, 3.8614231155189543`*^9}, {
   3.861423336445489*^9, 3.861423337017535*^9}, 3.861423589906907*^9, {
   3.8614241352337227`*^9, 3.8614242232882557`*^9}, {3.861424261107663*^9, 
   3.861424385338081*^9}, {3.8614360998802*^9, 3.8614361194898243`*^9}, {
   3.861436669108592*^9, 3.8614367007331123`*^9}, {3.861467228051468*^9, 
   3.861467326084627*^9}, {3.861467544610755*^9, 3.8614675511935797`*^9}, {
   3.8614712234088182`*^9, 3.8614712694367723`*^9}, {3.861471360981318*^9, 
   3.861471513146019*^9}, {3.8615187114984283`*^9, 3.86151875252699*^9}, 
   3.861518859174892*^9, {3.861523558261744*^9, 3.8615235614907923`*^9}, {
   3.8615236069554567`*^9, 3.86152362326784*^9}, {3.8615236673279953`*^9, 
   3.861523695646112*^9}, {3.8615242292446203`*^9, 3.8615242817205963`*^9}, {
   3.861524332968378*^9, 3.861524358341216*^9}, {3.86152445525476*^9, 
   3.8615245136449413`*^9}, 3.861634039010315*^9, {3.861634073493341*^9, 
   3.861634117263124*^9}, {3.861634238083836*^9, 3.86163424846392*^9}, {
   3.861634532620872*^9, 3.861634600572381*^9}, {3.861634678847238*^9, 
   3.861634708930567*^9}},ExpressionUUID->"8100a627-7e1b-4469-8899-\
c97cce37d2ef"],

Cell[CellGroupData[{

Cell["Definitions", "Section",
 CellChangeTimes->{{3.860260658044477*^9, 
  3.860260664569789*^9}},ExpressionUUID->"44bfb5d4-d821-464b-a599-\
42b2aa85d303"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Reconstruct", " ", "the", " ", "cartesian", " ", "coordinates", " ", 
      "from", " ", "the", " ", "obtained", " ", "solution", " ", "in", " ", 
      "cylindrical", " ", 
      RowBox[{"coordinates", ".", " ", "Note"}], " ", "that", " ", 
      RowBox[{"z", "[", "]"}]}], ":=", "z"}], ",", " ", 
    RowBox[{
    "which", " ", "does", " ", "not", " ", "need", " ", "an", " ", 
     "independent", " ", 
     RowBox[{"definition", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"r_", ",", "\[Phi]_"}], "]"}], ":=", 
     RowBox[{"r", "*", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", 
      RowBox[{"r_", ",", "\[Phi]_"}], "]"}], ":=", 
     RowBox[{"r", "*", 
      RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.860260672789164*^9, 3.860260704702405*^9}, {
  3.8603201038053303`*^9, 3.860320104920257*^9}, {3.86142330788623*^9, 
  3.861423351098844*^9}, {3.861423391377071*^9, 3.861423396546707*^9}, {
  3.861423445218329*^9, 3.8614234453807983`*^9}, {3.861423489870843*^9, 
  3.861423566721037*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"f9ff8b4e-7ff9-4ddc-b3e9-a27e4deddba9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "We", " ", "keep", " ", "the", " ", "radius", " ", "constant", " ", "as", 
     " ", "r"}], "=", 
    RowBox[{"1", " ", "throughout", " ", "this", " ", 
     RowBox[{"notebook", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"rCyl", "=", "1"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.861423735097191*^9, 3.861423757225622*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"1a999f19-1447-4281-9b20-b87595d5b8d8"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cylinder", "Section",
 CellChangeTimes->{{3.861423665092867*^9, 
  3.86142366974576*^9}},ExpressionUUID->"f246066c-4a29-415a-8dbd-\
e13c58e61af9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Draw", " ", "a", " ", "cylinder", " ", "with", " ", "radius", " ", "1", 
     " ", "and", " ", "height", " ", "2.", " ", "Here"}], ",", " ", 
    RowBox[{
     RowBox[{
     "\"\<ViewPoint\>\"", " ", "specifies", " ", "the", " ", "default", " ", 
      "orientation", " ", "of", " ", "the", " ", "plot"}], ";", " ", 
     RowBox[{
     "see", " ", "the", " ", "documentation", " ", "for", " ", "more", " ", 
      RowBox[{"information", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  
  RowBox[{"Cyl", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"rCyl", ",", "\[Phi]"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"rCyl", ",", "\[Phi]"}], "]"}], ",", "z"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Phi]", ",", "0", ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\[Pi]", ",", 
        RowBox[{"\[Pi]", "/", "2"}], ",", "2"}], "}"}]}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.861423290365738*^9, 3.861423290381706*^9}, {
  3.8614233715651913`*^9, 3.861423514798633*^9}, {3.8614235717618303`*^9, 
  3.861423574104793*^9}, {3.861423750380228*^9, 3.861423761881131*^9}, {
  3.86142386631166*^9, 3.861423899905717*^9}, {3.861437019198235*^9, 
  3.8614370194943743`*^9}, {3.861437120820775*^9, 3.861437132466872*^9}, {
  3.861437184593082*^9, 3.8614371898054123`*^9}, {3.861467372150755*^9, 
  3.8614673774176073`*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"eeac07c1-d90f-4bed-be13-76943f425a92"],

Cell[BoxData[
 FormBox[
  Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJyVnXmcntPZgMfSEFtEokFVkbFUJEg0tshY2tQImiqtSqjP8hEMat9VqVaL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     "], {{
       {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[2], 
        EdgeForm[None], Specularity[
         GrayLevel[1], 3], 
        StyleBox[GraphicsGroup3DBox[
          TagBox[{Polygon3DBox[CompressedData["
1:eJxFnXXcFcUXxve9u3vv9iuYYACKIArY3d3dDWJ3d3cHBnaLia3YhagodmNi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             "]], 
            Polygon3DBox[CompressedData["
1:eJwtnXkcFeMXxmfuPvfOvUVkpyikJFJIi0JFCoUQUURSIbtEKaUoS5QSsrVo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             "]], 
            Polygon3DBox[CompressedData["
1:eJwl1nmUT2UcBvBbg/mNH8maQUk5lS1SlvaTLNnH2JVlxjIihKKMpWxFm+XQ
MJbESZOypWNLKEOnnLJVlhTSSZZQR3Ui9XnP/eM59/0+7/M83/f+fve+762W
PSxz6LVRFE2FonA8GUWFxaOobGoUTUyLoqsm00tGUUXoZb5iIopq46uWiKJH
gg5Xr1gUdcJvVv/GXzQlikbTXCej3XXGvA/KWa9OgwyavviNPGt4T8toihuF
G8E3HBbi6uhRG/rSPc534pooOk+3X58K6lfS4l7D+G7Ep+txN64+FNEzBbrK
Kc9/S8ilyeU9oOd53AL6XN5yuGV0r9G8Dul6TsIXGjfUZ6O+/cI6YKDxStwc
/pPqn6A9b2n1DfTP85UsHq9/snoKDKTJgbk0q3kb6duI5kXa7eY/hWdwKTRj
ce+qq9HN1+tZdXXrvtn8A/j74WncVdfKuAau90Amb5bMSfr2c39v6HXY/R+C
bbjm6o/ovqe5JC/N7zZbXVGfJepBMmuqz/A217e1vMdpx/Jm4V7l36M+Q5vC
O522PO85+WdhF11Lmq34jTQj5TU2/oM3Q95w3vH4pdZ8ku5r/Dd6tKI7ZjxO
VhFzPXDdYTZNAa4ebi3fELq68i7QtpR3iuYXyNC3DG26uSdp/nQtx1PD9Q7Y
ru8R/su48epSMl8I/znvKjl3qrfhN7mHjbBBXhN57+E+UW8JPO5R3Pu4z+Qd
lXdF3gT19fwF6uEyG6ovWl87udl8faEtribvZBmreZ/BDcB9yDeUbpX6N3ye
8WHcUnNf4nbDjX7nMfLW4v613qtQLfzXuC7ycvQ8GJ4J43/0uAylZI3BT8O/
DIvNrQ/3BQXh+SwW3+MCWQthmvu4rO8W3mZ8b5WI37MncF/QXlL/CZvpMtRV
Q4YeQ9zzfNxZvr34juG5DXsE7jvem2Cyuj2+tPEOaGUuE9cRmsi5LRE/X7Pk
TZG3PGxE+EPyRvCtSMbPzu/qRvjVfGugQthfcO/gqoTfCeqEPUneEBET+KbJ
/I7m70T8zC2hOYGbKe9AeLfop6pzaZeY/4vuW/r++u4N75Sci7jfISX8b/h7
8felxe/iYdxcmbPUX4W9SG4rv9OjdG/K6Q0/0E1WV8ZvMd+Ibif9xJDFP8r8
jvBMQXPcDror4Z2nO8z/c9iX9Fhk/hvcLHMzcNvo/rOukbgauCvmh/LXc70r
Ld4HM9Tzw/5nvIcuHZ7CLUvG7895+XfSjsPVlzmM7mP1ZsiQ3xSfR5Md1mHu
DdwMmGj8t6xN+s+WNZCuPM8JusZyq9M0wU1XN4BJ9CPlF+BP8fTnrUQ3Xf0K
bMBdSo3PkQvq81A5vMP4Tbwl3EMSquNuwG3H7VQXwkpcM1yV8DzoMdh65pk/
E/YqvdfhjiXjM2wobVKflta2T48U3Fj1j3QnZB2H9TSP8d4qrzXdoJLx/vMe
XQSD5D2djM+NI3S7w3tIl8TVDeeHug9+kLorPss4OxGvaaGsTFwVOfugG+40
XTZuEc3iRLyvrqDrhKtKcxB60+XjOuAqqfemxv9plrp5Mn6/F+i7kP9LdU/8
TONZcC6sPbyr/D3d2we8OWGfoetNN49mfiLeG3f5TR7DHZU1mu5fus7qtrQ/
6dGBLjP0oMuTWdf883Sp4Uyh6UObH87URLw39lI/jM/jzZeZh28bzndraWx+
DW9RKJTXAn+EZlRq/Py3UQ+mu4tuBe5aKEM3Af+JfrXUK+jGyO+GGyA7JxG/
x/vNDwjnQHiuoKH+Cet9DjfO3Ni0eE2H5C3DN5QzQd71+NbyRtPlGo9Ji78J
drv2w52W9Wsi/p/fphuMq2XurHW3kNHJejtDU9ztdOPCN4Ee4+m2hDNAj3fp
8vX8Cp8MPcL5huuq7hLOb+PluBn83WR1h5PhLFO3oD8e9maoYNy+WPzdUdVa
Ooa9SD0lEX8TDODLgTPGtXEZ9E+EddB20mMabnr4psKtT8bn1VT1S1BR3Ube
HHkvJOKztDvdqmT8XfAibiL0wK1Oxvc+KZxv4XvD2o7AOp62/GX13W8dB2Bd
+O1xW635obDf8+/CfQ659P8DeQ9jNQ==
             "]]},
           Annotation[#, "Charting`Private`Tag$1179#1"]& ]],
         Lighting->{{"Ambient", 
            RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
           "Directional", 
            RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
            ImageScaled[{0, 2, 2}]}, {"Directional", 
            RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
            ImageScaled[{2, 2, 2}]}, {"Directional", 
            RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
            ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {{}, {}, {}, 
       {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwNzbErxHEch/EPV+7OgLO4GCRi+f2K2Fj8NpMysFjYRGxmUhSKFJt/4BQj
G3ILGxYiE5PuNiyK1/Du+X6eZ/j2zK9MLTdExJwNNUWcWpaPOMPNloiLQsSX
+wavuEnva9zSqtyv+wlvuVnvO9zWnrmc1eyBW9Aese5utsaiD1sjXrhV7RVz
XEnrwLz2zm1oH1jmylqCbVqN29fquOO/lO/Wx/GbO9Z+cFfLuH5tGv+4iha2
p81wqbaIBe7cinagLXEj2hoO+LPEV63d1rlR7RATrZO7ty474jKtgsNaL/dm
fXbCTWiXOKYl3KelNmj/ZxwyJw==
         "]], Line3DBox[CompressedData["
1:eJwVzb0vw2EUhuFT8VGaEB9LBWHApE0aNltNJjExWDpK1GjHYJEwMfEHINjY
hNSik7D43FgkbSSEQeL6DU+ec+775H2HSsuz5VRElKTQHHEixZaIU32ejvhs
j/i2V8yX2Iz5Sm/g19if/UHfYAvmL7xqfsQapSZ39n18kb8317FM4lsjUh0R
z9gK96KbsC4uq9PcG7bOveteLMtVvZUz17Btrq7z9k73g3zR/IPtcb960/0U
NsrNJX/iB9IgW9w8luOWdBt2JgPeyugyNsGt6m77sfuK7pE1bJLb0WPu+7Bb
6ZddrMgd6nFuGHuVETnCprknb10kf2MfkpeC/AO6/DQx
         "]], 
        Line3DBox[{1587, 1714, 1860, 993, 3827, 2039, 1015, 1873, 1017, 2046, 
         1054, 1886, 3830, 1056, 2053, 1093, 3744, 1899, 1095, 2060, 1132, 
         3749, 1912, 1134, 2067, 3786, 1171, 1925, 1173, 2074, 3789, 1210, 
         1938, 1212, 3858, 2081, 1249, 1951, 1251, 3866, 2088, 1288, 1964, 
         3868, 1290, 2095, 1327, 1977, 3871, 1329, 2102, 1366, 3760, 1990, 
         1368, 2109, 1405, 3765, 2003, 1407, 2116, 3802, 1444, 2016, 1446, 
         2123, 3805, 1480, 2029, 1841, 1844}], Line3DBox[CompressedData["
1:eJwV0DkvRGEUgOFDMTO3QEE3CDqNjGWi010UqiktEWox6PSWH6CyFPwAy0Qh
RoNmUKiUlvgDEkuh47nFm/d8eU++fPf2LlYry00RsYCRXMQ50nzEVSHiojWi
zr/ODb5DxfzAl9o9/zk/8wvmzW/8ihw+8YUju0vaj/kbLVlPIprbIvK8riVc
QIdW5ETr5C2tm7tQ1B7dVTIPYkcb5iG02+/TU/M4DrVJvrY/wf3aNM/gWJvj
W22WS1qVV1DXety1Zl7FqLbBm6jZb+jb2bswpu3ygP09ftIOeB+pdsJl7ZTf
tRqfYSr7R+66yd6Aj+w7UMY/xy4zvg==
         "]], 
        Line3DBox[{8, 460, 2807, 23, 473, 2820, 38, 486, 2833, 53, 2514, 499, 
         68, 2528, 512, 83, 2542, 525, 98, 2557, 538, 2846, 113, 551, 2859, 
         128, 564, 2872, 143, 577, 2885, 158, 2574, 590, 173, 2588, 603, 188, 
         2602, 616, 203, 2616, 629, 218}], 
        Line3DBox[{247, 246, 2902, 646, 265, 2916, 660, 279, 2940, 674, 2941, 
         293, 688, 2958, 307, 702, 2972, 321, 716, 2986, 335, 3000, 730, 349, 
         3014, 744, 363, 3028, 758, 377, 3052, 772, 3053, 391, 786, 3070, 405,
          800, 3084, 419, 814, 3098, 443, 446}], Line3DBox[CompressedData["
1:eJwVzz8vQ3EUxvEjQTXSa6KLpKoLJqbeWGwSiS4Ge2vHxOQF+BOJyYp4AyQM
iE0XSTuyIRgYa6Bh8LnDk+ec7/fkd3PLjbWl1Z6IqEvaH3ElC7mIa30zENE1
t/Sdfdnc1NtJRBsLeZUWtsJ9Z9z8huXkRx7sJ/g6/2juYokU8hG9QxHP2Bb3
ohNsmBvXg9wHtsN96go2yrW9VTV3sEPuS6f2ovsKv2j+xU65P73vvoZNcfXs
m/iZ9MkB18BmuA1dwG6l7K1Eb2Ipt6tH7Ofu73VR9rA57khPuy9l/ydjcozN
cxe6yk1g7zIpl1iNe/JWM/NYR1KZlX9kLjQv
         "]], 
        Line3DBox[{1593, 1724, 1866, 1000, 3828, 2042, 1036, 1879, 1038, 2049,
          1075, 1892, 3832, 1077, 2056, 1114, 3747, 1905, 1116, 2063, 1153, 
         3750, 1918, 1155, 2070, 3787, 1192, 1931, 1194, 2077, 3792, 1231, 
         1944, 1233, 3864, 2084, 1270, 1957, 1272, 3867, 2091, 1309, 1970, 
         3869, 1311, 2098, 1348, 1983, 3874, 1350, 2105, 1387, 3763, 1996, 
         1389, 2112, 1426, 3766, 2009, 1428, 2119, 3803, 1465, 2022, 1467, 
         2126, 3808, 1494, 2035, 1849, 1852}], Line3DBox[CompressedData["
1:eJwVzjkvRGEUgOFDYplEDBrRTCK2RiMaZkyhk0xiq9TDKElUlsIfsLVahj9A
YowQoqCRWDqdgvEDVJbEc4s37/nue+53b3dxeXapLiKKyDZGXKLQFHHVHFFp
deYf50d+wpz5havaM9fjHR8oaZ98odU4he/kfZQ9W9H/zL9oQzoV0ZA286bW
we3o1Hq5RevjLW2A+5FJ/sNdo+Ys9rUxzqEr2dcnzVM41mb4xv40D2rzvIAT
bZFvtRIPa6u8hmutx10b5vXkO9o27+DU/oO+Z97FuHbAQ/YP+VU74jImtDMe
0Spc06p8nvyf9uauO/M9vrQc8vgHlnE2Cw==
         "]], Line3DBox[CompressedData["
1:eJwVzb0rxAEcx/GvxcOAgX9AGVjskpPJQulucZOjcKU8ZGCgriykiyN5uISU
c5vB5vJQMhrEZDVwg92Cl+Hd5/t7v3/9fm3js8mZmogYw2ptxBk+6iIqDRHX
6G6OWOFOcVkf8aaV+MemiHO7yB/jQnvStrkHrWDn+SOcaPda+/+3+GVM80Xs
a2XvX+lZfgoT/AG++C29pKX4JEb5PVS1Ne1QS/C9SPPP/K7NaXmtk+9Ao3+n
+B0saTmtlb/xfosd4guY0xa0X1vRfuwAv4mse1L75qvuT/TzeWTcRT6tv7pf
0MNv4J0f8Tyo3dlbdPHrGHb38WV3wv4BPnY5Yg==
         "]], 
        Line3DBox[CompressedData["
1:eJwVzT8ohHEcx/Gv5bDcTcp6g+UMyihFJgvlusVNPAOdRC4DhiuyMChM/iyk
3D0mykixsFFKlEkZdKtJiZfh3ef7e7/refLJfHGuJSISrGciTvDZGlHAVXtE
Xy6ixl20RZzjjc+jrvVqS1rKN/DAd3Oddlevasf8EW65Li1na9qsts/vIc1G
XPIZVLQpbYffxqlW53+4kjZhX7hNbQMH2hc3oJXtk7bGr2JLa3IFLevfJfcK
v/zftXfvDi2jjbqr/AIWtV/feeVCH7YzfAXT2rf2yDW9h2xiJ3HIl/U77tm7
35btBz9uR7Rr7sbdY+/5onsMg1rKneEPmyg3Pg==
         "]], 
        Line3DBox[CompressedData["
1:eJwVzT0oxHEcx/HvLY7FmZSRwXKLXYpMFgo3ncVR5HE4BlFXHibKcCfJbc5w
ORMZKRYjpZSyUApXJpOSl+Hd5/d7v/8P7bnF4YVEROSw1RBxjI9kRBqXTRHd
qYgCd94YcYZnvgMHzRFVfUWr8Se449uwr5W0vFbhj3DDd/pWiy1o81qZP/x/
1/MXfBIz2pRW4r/4oq3yv1xGG7c73Ke2bcvaN9erZe0Dv8lvYFerc2kt5d8Z
5zV+Fevaq/ue51v1IeclPo9l7cm9qCW0Aec5fhbT2g9/z9Xd++2kfecmbFa/
5R6de+yYfdOydlC74q6du+yofdFGbJ9W407xB46xOWk=
         "]], 
        Line3DBox[CompressedData["
1:eJwV0L8rxHEcx/G3xc9isWPzB7iRScpNIiYcV8pyZ3CWK2XxMyQdSe5CMWHw
Y5IMiGK93Y/BoliYDB6GZ6/v5/n89P3WtyU90ZutiIhRzFVGHOKzKuK2JuIG
7Q0RM9w+LqojXrUz/r4+4tTm+V0ca2WtxN1pRZvjSzjQHrRW71rkF5Dld1DU
jty/1HP8JMb5bXzxG/qJluKHkea38KGtaHtaku/GIF/mN+2sVtASfBsafXuA
L2Bam9ea+Wv3m2wPv44pLa/VcVdarU3ya8hoGe2X//H8jU5+FWOeR7QX+4wO
bhnv7g4592lP9hEJfglvWr9zl3b+/3/xBw1EOmE=
         "]], 
        Line3DBox[{1671, 1703, 2032, 1487, 3902, 1665, 983, 2019, 1454, 3894, 
         1659, 970, 2006, 3887, 1415, 1653, 957, 1993, 3881, 1376, 1647, 944, 
         3757, 1980, 1337, 1641, 931, 3752, 1967, 1298, 1635, 3801, 918, 1954,
          1259, 1629, 3798, 905, 1941, 1220, 3861, 1623, 892, 1928, 1181, 
         3850, 1617, 879, 1915, 3843, 1142, 1611, 866, 1902, 3837, 1103, 1605,
          853, 3741, 1889, 1064, 1599, 840, 1876, 1025, 1590, 3785, 826, 1863,
          1718, 1719}], Line3DBox[CompressedData["
1:eJwVz6tLQ2Ech/GfCF5gaNIoLAn+ATNqEkHTwEuaOkTBsFmcZSgYvAUtchSD
C4Ka1CBegk2LsOqiIIYVw0mCQfwsPHzf93nOdjjZYjlfaouIBex2RFwh7YzI
4bU7YqQ3Yot76Iq4xxc/iNOeiDu9qt3w12jwAzjRalpFu+Qv8MYP+a8+u6+t
ajX+rPVbzz/zGaxpK9oxn/KJveXbMa8taofct3Zgz/lfbkIr2Aa/w28j0VIu
p/V796zzJr+BPa3pnng+q+ed1/kKqtqH+5GW0Sady3wJZe2Pf+d+3Mfssl1q
fQtf1Ovcp/uonbNNvmCntBeu7jxsZ+w0xvlH9yf8AxFeORs=
         "]]}, 
       {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwVzVkug3EYhfHXjZhiCagad2GmZqXKlYTEJZug5nme1sGFBeg2WIG2ZhK/
Xjw5533OP9+XWFxNr1RExALy1RFrdRHrGK2NaJBblRGvNRE5fQNjfKY+4gld
fAGb5XcYtz3zjXo3X8S2voMcP2Fv0nv4Enb1Ar+ESVvC3cu/YU8v8vtyytYs
+/h33PMH7kOkbUnZz3/gSD/GNN9S/pe3L/i0nbhPMWNrlXl+gP/CmfscGVu2
KmKQ+8YFd4lZvk0OcT+40h+9y/Lteor7xbVe8t0bOWfrkMP8Hx74W/cd5m2d
coRfxj/aTDbe
         "]], 
        Line3DBox[{2506, 1529, 2906, 832, 3812, 2814, 1005, 2907, 3813, 833, 
         2815, 1008, 2908, 3814, 834, 2816, 1011, 3719, 2909, 835, 2817, 1014,
          3720, 2910, 836, 2818, 1017, 2911, 837, 2819, 3769, 1020, 2912, 838,
          2820, 1023, 2913, 839, 3815, 2821, 1026, 2914, 840, 2822, 1029, 
         2915, 3816, 841, 2823, 1032, 2916, 842, 2824, 1035, 3721, 2917, 843, 
         2825, 1038, 2918, 844, 2826, 3770, 1040, 2919, 1503, 3602}], 
        Line3DBox[CompressedData["
1:eJwNzckugwEYheHPDq0a2rJla1bzvHIDFliKRFTxt0pEREQs3QJqnq7BJbgI
axegLD2Lk/O+5/uHno3yctIQEevy2RTRnYnYao4opiJ60xFXfEVSvMaLbiW8
aruWPlua3+ptt138be/nA9LC7/SS7VISPsiHJIPv9Y+95N0KH+Yj0oofdN1t
x63KC3xU2vBXo3/ZD/GYbVza8aPesx/hCbzpuQ78hBP7MZ7EN747pbP8WZfd
TvCavSbTthx/0RW3UzyDZyWPX/Wv5/bdzvgcn5dO/Kb/3Kpu53yBL0oX/rC/
4wO3C57jecnKP6hhK6I=
         "]], Line3DBox[CompressedData["
1:eJwNytVNAwAURuHLCwkSdihTMAcbQJAQAg2BUtpSSiluK6BPuLssgBYfBQ3f
w5+Te85NNCcbuysiosk+qiLq6yLmqyNKNRFzuOput3ftujZilitqM7jCX3Fv
2iVOcwVtCpe1C+5VO8dJLq9N4Jn7hT/FP3/jXE4bwxPuWTvGX22Uy2glPOKe
tDb+x0a4tFbEQ62sHeCwO8UXcMlfqz1q+9oQ16vlcZHf4x60XRzkerQcLmg7
3L22jVkuqZUrI7bcd/wmfvvLaF3aAG5wt9o6fmlprlPrxzXuRmvhPy3FdWh9
2OBO2D/3F0H5
         "]], Line3DBox[CompressedData["
1:eJwNzNVRA1AQQNEN8oEM1MBAEzSAfVJCCoAm0CBJSHCXUAXM4O7uLmXA+di5
b+/deTXJ9ta2REQkzW9ZRF1VRKE8IlsRsYT3lRGl1RE/2p33IpfRFnDZ7S33
rd3gPJfWSty3aNfcl3aFc9qgNouX9k/+Apvd5c2ANqOdcx/aGRb7Z5rr16bw
lHvXVt2feE9yfdoEHtvftCMct6f4MTy0F/nnVTvwHuV6tREs+Gefe9H2cJjr
0RLum7Rd7lnbwbzWrYXWqG1zT9oWNthzpkvPudvkHrUN/OOHuE4ti+vcg7bC
r3lnuA4tjfVcrfkH5YVDzg==
         "]], Line3DBox[CompressedData["
1:eJwVz0dSAmEQQOHGAA4z6hlcqHfQW3gEVq70LubsTXSvNzBnQUCJ5vTN4tXr
+V9XF0xUFucWChFRQT+JmBqLmMZ+GpGNRqTIxiN6WmIuY08b4WN7Je5qw1zE
rpbaHzIPoqMVeAA7WvBfFtH2/sO/WHNnW/s2f6GlfXDZnU/e0t75DS/aof2+
+RWbWo+7eNba3MGG91a+j8SdptbMd7CuNfjInTo3tBo/5b8l/2/2q+ZH1LV7
fsCqVtLuzLf5vnbNN3lza0W/Ml+ipl1w0f68tqyd+z5DVTvwdmI+xZI263sG
k/gHoRVFRg==
         "]], Line3DBox[CompressedData["
1:eJwV0Mcyg2EYxfHHUp8wk0KCYBgs2LBgI3qLEjXssicL4yrci97dhXoptn7f
4sxzzvk/7/uVYq1eOWuIiBr9NUaMtEWM0lVzxGxLxAe/0RSRlVOtER10zVf1
n1TGcnJan6Eb/lj/RZtYl5zXF+hSdyuX3LuFdfNFfao94hS7k+ewbSzPDyXP
w4bNe3ke28EKfN1+JzaGPcgLWAXr4cd1E/TIL+q/7e5ivfKkfoqe+CXsB9vD
+uRp/Qw98yf6X9rHism/0JfohV927kDfn9yffLf3OLf7Kq9gh9gAv4ZlsXXz
TV7FjrBB/sJ+Ditj73JGrmJp8x/EVyer
         "]], Line3DBox[CompressedData["
1:eJwV0EdKg2EURuEbdaLyJwETsYBdiCYKFlAhKqhYwJFLyMxCLLgge3cn1s2I
XZ8MDud/7/kgkN7K7kY1FREVNDRFFNMRJdw3R6wnEa++D1GvrdpruNNW+MV9
meu0RV7CrXbg/owFO6XN8TxutFkuI9xnuDUTse/ttTZtT+GvMWKC89okX2nj
PIZfbc/7nDZqX2ojXMKPNsTDuHAv8JO3VXxrA/YgzrV+fnTv4y+tm3twpu24
P6DL/tQ6uBOnWtbvtvtuw4eW54zbtvcnes5uwbuW5bS2pR1rmdrGm7bplmiJ
fVT7X+wyCvgHnbIqZQ==
         "]], Line3DBox[CompressedData["
1:eJwVzzdWw1AYROGfgobYEioKMhhYA1QkYxkTnC3b0MFGgBURbDI7gC0Q9sCn
Ys6buffpSJpJL5OLgYhIZXAoYnUsIie3wxHbIxGb+rfM2vujEXm506vYp5Q9
M2cf4AW513/wHc9WuHk7wYtyhT/Yu1yVW9AP8ZJccz17j6txi/oRPjUecezs
Z+/n6tyS3nP/BD+VRzvPNbhlvYxV5Cn7LnzL3V9Zyb4br8mzXuC+8Gb233Yd
b8iL/ocnfIvL2U28Ja96EU/xNT3F2nLj/lv2P1ybW9c7+LTv7zrf7RLX4Tb0
vvtn+Ll82JN2l5tw/gPK6S8k
         "]], Line3DBox[CompressedData["
1:eJwVz7dRA1EYReGfhACbgwiogBm8bwBIFOCtcELI4PoAmkDCUwNkeE8XmA74
Nriz957z9s1ua6aULlZFREaqayLaGiKOPG9rI8brIibkG2u3s/URZe5On8PK
Msl32BtchbvXf/ApfFo67Rw3gu3Lgz2Dz0qXvsmN4gfymNyLz0u3nudSjRHH
7n2yF/BF6dGvnS/wJ9yzvYRnpFcv4qf4i76Mrciv8312iTvjXvVVvIKvefbb
W9w596b/4et4Vgbsbe6Ce0/+FcvJoL6Djzl7KB/J/+B5GdJ3uRbff+m9T7uA
F2VYv3F+j7/ivuxmOyVN8g8i+DW2
         "]], Line3DBox[CompressedData["
1:eJwV0FdKA2EYheHPK8G6AhOjG3AH9g5euABLFmBsMUYTY9mBu7CCve9DRERE
REREXIHPf/Ey55x35p9hcvnC5FxdRORR3xDR1RJx4vrYGFFoitjTp9CtF5sj
Trknedq2j3n39Ogr3Bn3LM/YD7DA9eolbkLfxYu+aF9Cn7zKZVojzj37qi/b
i+iXy1yWu+De0jvsJQyk7Kx27pJ7T+fYyxiU1zx3Zf9I2Xbo3lkM6evcNfeZ
Mndkr7gO6xXuhvuS8/ZjVLkRvcrdct/yhq2G0ZTtOd9xx/3om/YtjMk1roO7
5371bfsOxtM/cXYn98D96Rk9izb8AyUwOD0=
         "]], Line3DBox[CompressedData["
1:eJwNzcdJhFEYRuHPnc44M8YCBPNOC7AFwRKmAGdr2JhzDnUY1+acc0BERERE
RMQGfBaX895zfu5fkc21tOZFRNYpT0Q0piMe8C8ZcY+r7p1OmT2firjDX+0W
V/g5rtSexRv80a5xWZvhSuxpvMJv7RKn3ItxEuszERf2l3aOE1wRjmOddmZ/
aqc4xmWww9u12on9oR3jqJbGETzCd/4Ql3zb7qTsYe0A37R9XOSHuEJ7EPfw
VdvFBW2AS9r9uIMvWo3/Nmt9XILrxWpu237Wt7CHK8BurNI27SdtA7u4fGzz
RqW2bj9qa9jENTj/zoA9VA==
         "]], Line3DBox[CompressedData["
1:eJwNzDVWAwAQRdFJi3a4BUr8QJ8tQGAFWQDshgR3twpWAIvA3a3B/RZz3p/3
50wy05/uS0RExjTkRXQWRTxhoiDiEdcLI9qLI+rlNfkBQ3ePm25XuaS8gnf4
lx/R5r5Xt8zVcUt4i7+6G1y01+IC9rjLmR/dNTfP1eActvpzJX/rLnGWq8Zt
9zPyhfylO8dpexVO4Rl+8qc4aW/xp1KekE/wQ3eMG/6McxXyGB7hu67ZfVo3
ypVzI3iIb7omXbdumCvjhrDLnjWv+gNukCvFHDa635dfdHuY5Upwy/2AvCs/
63YwxXWYfyEBQIc=
         "]], Line3DBox[CompressedData["
1:eJwVzNVRA1AQQNHFIURqYAZ3Akn4hBYoIQVAAzQCVeDuEtw9wSvh8HHn7nt3
Z1uKUxOTVRFRxFAiIp+OKCCTjPhNRfxgNBMxqH2Zv5HWPrli74MHtAq/I6UV
7JfNb+jXXvgVSe2Zn9Dn/4EfMetOs3ZvvkOvdsN5d245oV3zFXq0E/sX5ks0
aed8hu7/xqdo9F/iY+Tc6dIOzUdo0A647M4+d2q7vId6bcT+jnkbHdomb6FO
G9Y2zOto11Z5DTNu1eor5mW0aUuctT+t1WiL3gto1Ur+5szzqNbGvceQwx9q
djlO
         "]], Line3DBox[CompressedData["
1:eJwV0FdOgmEUBuGDDUWavV+4BRSVouzBJbAAXYFdd2mNvWPv5eFiMrxn/uRL
mKwvLy4lIqKOWioin43owUQ6IsdH2MGCluEsxrU0H6Ib81oXpzCmbfMBOlHV
OjiJUa2d21Bxb+VaLmKLR7QWTqCs/WW8qYU9rP3aPyhpm803tW97SPviT8xp
7/yBQfc33vftBma1F/sVA9oz77k/8Yz2wI/o19bdd9Gwi9od36NPq3r31u8b
TGvXXHFb832vfmVfYkq74LK22vxPtXP7DAVtxa2kndp57YSP0dD+AfQBM5A=

         "]]}}},
     VertexNormals->CompressedData["
1:eJztXXl8DWfbPoJQlKItShuqSJRaqyra4KWIBFlI7GmDRBJ98ZYiVNSWiEqo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      "]], {}},
   Axes->True,
   BaseStyle->{FontFamily -> "Arial"},
   DisplayFunction->Identity,
   FaceGridsStyle->Automatic,
   ImagePadding->Automatic,
   Method->{
    "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}},
   PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}, {
     Automatic, Automatic}},
   PlotRangePadding->{{
      Scaled[0.05], 
      Scaled[0.05]}, {
      Scaled[0.05], 
      Scaled[0.05]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic, Automatic},
   ViewPoint->
    NCache[{Pi, Rational[1, 2] Pi, 2}, {
     3.141592653589793, 1.5707963267948966`, 2}]], TraditionalForm]], "Output",\

 CellChangeTimes->{{3.861423426532198*^9, 3.861423463910859*^9}, {
   3.8614234992282057`*^9, 3.861423502794867*^9}, 3.8614235761322403`*^9, 
   3.8614237623806267`*^9, {3.8614238786605577`*^9, 3.861423900764546*^9}, {
   3.861424489958674*^9, 3.8614245035457973`*^9}, 3.8614367526716347`*^9, 
   3.861436792622303*^9, 3.861437048296826*^9, 3.861437224376885*^9, 
   3.861524195260643*^9, 3.861633592633099*^9, 3.861633698117963*^9, 
   3.861633961075529*^9, 3.86163402745784*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"423b9d1c-dadf-477a-a2de-7b64150e29d8"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Two Points on the Cylinder", "Section",
 CellChangeTimes->{{3.861423672587376*^9, 
  3.861423683126904*^9}},ExpressionUUID->"12e73c43-bb13-4fbe-9fbc-\
97cb075b0d0d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Define", " ", "two", " ", "points", " ", "on", " ", "the", " ", 
     "cylinder"}], ",", " ", 
    RowBox[{
    "which", " ", "we", " ", "want", " ", "to", " ", "connect", " ", "via", 
     " ", "the", " ", 
     RowBox[{"geodesic", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]1", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"z1", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Phi]2", "=", 
     FractionBox["\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"z2", "=", "1.5"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p1", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"rCyl", ",", "\[Phi]1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"rCyl", ",", "\[Phi]1"}], "]"}], ",", "z1"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p2", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"rCyl", ",", "\[Phi]2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"rCyl", ",", "\[Phi]2"}], "]"}], ",", "z2"}], "}"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8614236303247633`*^9, 3.861423655420883*^9}, {
   3.861423689474753*^9, 3.86142372756767*^9}, {3.861423766216509*^9, 
   3.8614238148333406`*^9}, {3.8614239918516397`*^9, 3.861424038389654*^9}, {
   3.8614242348999567`*^9, 3.8614242499834013`*^9}, {3.861436070018252*^9, 
   3.861436079360998*^9}, {3.861436265616164*^9, 3.861436287850026*^9}, {
   3.861436769586781*^9, 3.8614367758494987`*^9}, {3.861524175574191*^9, 
   3.861524177849152*^9}, {3.861524219383442*^9, 3.861524221922221*^9}, 
   3.861633562737974*^9, {3.861633685016861*^9, 3.8616336881700163`*^9}, {
   3.86163395001589*^9, 3.8616339501462*^9}, {3.861633995557437*^9, 
   3.861634005455916*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"a4fca465-32e7-4bf1-9e7f-4e24847d2ac5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Plot", " ", "the", " ", "two", " ", "points", " ", "into", " ", "3", "D", 
    " ", 
    RowBox[{"plots", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"p1Plot", "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
        RowBox[{"Point", "[", "p1", "]"}]}], "}"}], ",", 
      RowBox[{"ViewPoint", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\[Pi]", ",", 
         RowBox[{"\[Pi]", "/", "2"}], ",", "2"}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"p2Plot", "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
        RowBox[{"Point", "[", "p2", "]"}]}], "}"}], ",", 
      RowBox[{"ViewPoint", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\[Pi]", ",", 
         RowBox[{"\[Pi]", "/", "2"}], ",", "2"}], "}"}]}]}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.861423912589551*^9, 3.861423961729425*^9}, {
  3.861437025317565*^9, 3.861437026712837*^9}, {3.861467392972975*^9, 
  3.8614674051478167`*^9}, {3.861634750360816*^9, 
  3.8616347504808083`*^9}},ExpressionUUID->"f62f42a1-51c9-4321-b592-\
25d0387766b4"],

Cell[BoxData[
 FormBox[
  Graphics3DBox[
   {RGBColor[0, 0, 1], PointSize[0.025], Point3DBox[{1, 0, 0.5}]},
   ViewPoint->
    NCache[{Pi, Rational[1, 2] Pi, 2}, {
     3.141592653589793, 1.5707963267948966`, 2}]], TraditionalForm]], "Output",\

 CellChangeTimes->{{3.861423948670727*^9, 3.861423962019231*^9}, {
   3.861424003152835*^9, 3.8614240400092907`*^9}, {3.861424236354166*^9, 
   3.861424251158202*^9}, {3.8614244900207367`*^9, 3.861424503594067*^9}, 
   3.861436089504821*^9, 3.8614363353794317`*^9, 3.861436752752512*^9, 
   3.861436792764071*^9, 3.861437048458234*^9, 3.861437224481708*^9, 
   3.861524197482184*^9, 3.8616335930098457`*^9, 3.861633698398745*^9, 
   3.861633961330192*^9, 3.861634027591214*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"b17ffd02-3181-4608-bcd1-da6c6a41a058"],

Cell[BoxData[
 FormBox[
  Graphics3DBox[
   {RGBColor[0, 0, 1], PointSize[0.025], Point3DBox[{0, 1, 1.5}]},
   ViewPoint->
    NCache[{Pi, Rational[1, 2] Pi, 2}, {
     3.141592653589793, 1.5707963267948966`, 2}]], TraditionalForm]], "Output",\

 CellChangeTimes->{{3.861423948670727*^9, 3.861423962019231*^9}, {
   3.861424003152835*^9, 3.8614240400092907`*^9}, {3.861424236354166*^9, 
   3.861424251158202*^9}, {3.8614244900207367`*^9, 3.861424503594067*^9}, 
   3.861436089504821*^9, 3.8614363353794317`*^9, 3.861436752752512*^9, 
   3.861436792764071*^9, 3.861437048458234*^9, 3.861437224481708*^9, 
   3.861524197482184*^9, 3.8616335930098457`*^9, 3.861633698398745*^9, 
   3.861633961330192*^9, 3.86163402760931*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"a2858f77-15ce-4740-967b-780f752145a7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Draw", " ", "the", " ", "cylinder", " ", "and", " ", "the", " ", "two", 
    " ", "points", " ", "into", " ", "a", " ", "single", " ", 
    RowBox[{"graphic", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Show", "[", 
   RowBox[{"Cyl", ",", "p1Plot", ",", "p2Plot", ",", 
    RowBox[{"ViewPoint", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\[Pi]", ",", 
       RowBox[{"\[Pi]", "/", "2"}], ",", "2"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8614236577960587`*^9, 3.8614236628552113`*^9}, {
  3.861423799952744*^9, 3.861423824986292*^9}, {3.8614239054313307`*^9, 
  3.8614239093758497`*^9}, {3.861423971527254*^9, 3.861423973643961*^9}, {
  3.861424079837096*^9, 3.861424091576692*^9}, {3.861436906660925*^9, 
  3.861436932493596*^9}, {3.861436965918157*^9, 3.8614369700759687`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"33b37129-4258-4463-87ba-1b209293418f"],

Cell[BoxData[
 FormBox[
  Graphics3DBox[{{GraphicsComplex3DBox[CompressedData["
1:eJyVnXmcntPZgMfSEFtEokFVkbFUJEg0tshY2tQImiqtSqjP8hEMat9VqVaL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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[2], 
         EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[
           TagBox[{Polygon3DBox[CompressedData["
1:eJxFnXXcFcUXxve9u3vv9iuYYACKIArY3d3dDWJ3d3cHBnaLia3YhagodmNi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              "]], 
             Polygon3DBox[CompressedData["
1:eJwtnXkcFeMXxmfuPvfOvUVkpyikJFJIi0JFCoUQUURSIbtEKaUoS5QSsrVo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              "]], 
             Polygon3DBox[CompressedData["
1:eJwl1nmUT2UcBvBbg/mNH8maQUk5lS1SlvaTLNnH2JVlxjIihKKMpWxFm+XQ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              "]]},
            Annotation[#, "Charting`Private`Tag$1179#1"]& ]],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {{}, {}, {}, 
        {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwNzbErxHEch/EPV+7OgLO4GCRi+f2K2Fj8NpMysFjYRGxmUhSKFJt/4BQj
G3ILGxYiE5PuNiyK1/Du+X6eZ/j2zK9MLTdExJwNNUWcWpaPOMPNloiLQsSX
+wavuEnva9zSqtyv+wlvuVnvO9zWnrmc1eyBW9Aese5utsaiD1sjXrhV7RVz
XEnrwLz2zm1oH1jmylqCbVqN29fquOO/lO/Wx/GbO9Z+cFfLuH5tGv+4iha2
p81wqbaIBe7cinagLXEj2hoO+LPEV63d1rlR7RATrZO7ty474jKtgsNaL/dm
fXbCTWiXOKYl3KelNmj/ZxwyJw==
          "]], Line3DBox[CompressedData["
1:eJwVzb0vw2EUhuFT8VGaEB9LBWHApE0aNltNJjExWDpK1GjHYJEwMfEHINjY
hNSik7D43FgkbSSEQeL6DU+ec+775H2HSsuz5VRElKTQHHEixZaIU32ejvhs
j/i2V8yX2Iz5Sm/g19if/UHfYAvmL7xqfsQapSZ39n18kb8317FM4lsjUh0R
z9gK96KbsC4uq9PcG7bOveteLMtVvZUz17Btrq7z9k73g3zR/IPtcb960/0U
NsrNJX/iB9IgW9w8luOWdBt2JgPeyugyNsGt6m77sfuK7pE1bJLb0WPu+7Bb
6ZddrMgd6nFuGHuVETnCprknb10kf2MfkpeC/AO6/DQx
          "]], 
         Line3DBox[{1587, 1714, 1860, 993, 3827, 2039, 1015, 1873, 1017, 2046,
           1054, 1886, 3830, 1056, 2053, 1093, 3744, 1899, 1095, 2060, 1132, 
          3749, 1912, 1134, 2067, 3786, 1171, 1925, 1173, 2074, 3789, 1210, 
          1938, 1212, 3858, 2081, 1249, 1951, 1251, 3866, 2088, 1288, 1964, 
          3868, 1290, 2095, 1327, 1977, 3871, 1329, 2102, 1366, 3760, 1990, 
          1368, 2109, 1405, 3765, 2003, 1407, 2116, 3802, 1444, 2016, 1446, 
          2123, 3805, 1480, 2029, 1841, 1844}], Line3DBox[CompressedData["
1:eJwV0DkvRGEUgOFDMTO3QEE3CDqNjGWi010UqiktEWox6PSWH6CyFPwAy0Qh
RoNmUKiUlvgDEkuh47nFm/d8eU++fPf2LlYry00RsYCRXMQ50nzEVSHiojWi
zr/ODb5DxfzAl9o9/zk/8wvmzW/8ihw+8YUju0vaj/kbLVlPIprbIvK8riVc
QIdW5ETr5C2tm7tQ1B7dVTIPYkcb5iG02+/TU/M4DrVJvrY/wf3aNM/gWJvj
W22WS1qVV1DXety1Zl7FqLbBm6jZb+jb2bswpu3ygP09ftIOeB+pdsJl7ZTf
tRqfYSr7R+66yd6Aj+w7UMY/xy4zvg==
          "]], 
         Line3DBox[{8, 460, 2807, 23, 473, 2820, 38, 486, 2833, 53, 2514, 499,
           68, 2528, 512, 83, 2542, 525, 98, 2557, 538, 2846, 113, 551, 2859, 
          128, 564, 2872, 143, 577, 2885, 158, 2574, 590, 173, 2588, 603, 188,
           2602, 616, 203, 2616, 629, 218}], 
         Line3DBox[{247, 246, 2902, 646, 265, 2916, 660, 279, 2940, 674, 2941,
           293, 688, 2958, 307, 702, 2972, 321, 716, 2986, 335, 3000, 730, 
          349, 3014, 744, 363, 3028, 758, 377, 3052, 772, 3053, 391, 786, 
          3070, 405, 800, 3084, 419, 814, 3098, 443, 446}], 
         Line3DBox[CompressedData["
1:eJwVzz8vQ3EUxvEjQTXSa6KLpKoLJqbeWGwSiS4Ge2vHxOQF+BOJyYp4AyQM
iE0XSTuyIRgYa6Bh8LnDk+ec7/fkd3PLjbWl1Z6IqEvaH3ElC7mIa30zENE1
t/Sdfdnc1NtJRBsLeZUWtsJ9Z9z8huXkRx7sJ/g6/2juYokU8hG9QxHP2Bb3
ohNsmBvXg9wHtsN96go2yrW9VTV3sEPuS6f2ovsKv2j+xU65P73vvoZNcfXs
m/iZ9MkB18BmuA1dwG6l7K1Eb2Ipt6tH7Ofu73VR9rA57khPuy9l/ydjcozN
cxe6yk1g7zIpl1iNe/JWM/NYR1KZlX9kLjQv
          "]], 
         Line3DBox[{1593, 1724, 1866, 1000, 3828, 2042, 1036, 1879, 1038, 
          2049, 1075, 1892, 3832, 1077, 2056, 1114, 3747, 1905, 1116, 2063, 
          1153, 3750, 1918, 1155, 2070, 3787, 1192, 1931, 1194, 2077, 3792, 
          1231, 1944, 1233, 3864, 2084, 1270, 1957, 1272, 3867, 2091, 1309, 
          1970, 3869, 1311, 2098, 1348, 1983, 3874, 1350, 2105, 1387, 3763, 
          1996, 1389, 2112, 1426, 3766, 2009, 1428, 2119, 3803, 1465, 2022, 
          1467, 2126, 3808, 1494, 2035, 1849, 1852}], 
         Line3DBox[CompressedData["
1:eJwVzjkvRGEUgOFDYplEDBrRTCK2RiMaZkyhk0xiq9TDKElUlsIfsLVahj9A
YowQoqCRWDqdgvEDVJbEc4s37/nue+53b3dxeXapLiKKyDZGXKLQFHHVHFFp
deYf50d+wpz5havaM9fjHR8oaZ98odU4he/kfZQ9W9H/zL9oQzoV0ZA286bW
we3o1Hq5RevjLW2A+5FJ/sNdo+Ys9rUxzqEr2dcnzVM41mb4xv40D2rzvIAT
bZFvtRIPa6u8hmutx10b5vXkO9o27+DU/oO+Z97FuHbAQ/YP+VU74jImtDMe
0Spc06p8nvyf9uauO/M9vrQc8vgHlnE2Cw==
          "]], Line3DBox[CompressedData["

1:eJwVzb0rxAEcx/GvxcOAgX9AGVjskpPJQulucZOjcKU8ZGCgriykiyN5uISU
c5vB5vJQMhrEZDVwg92Cl+Hd5/t7v3/9fm3js8mZmogYw2ptxBk+6iIqDRHX
6G6OWOFOcVkf8aaV+MemiHO7yB/jQnvStrkHrWDn+SOcaPda+/+3+GVM80Xs
a2XvX+lZfgoT/AG++C29pKX4JEb5PVS1Ne1QS/C9SPPP/K7NaXmtk+9Ao3+n
+B0saTmtlb/xfosd4guY0xa0X1vRfuwAv4mse1L75qvuT/TzeWTcRT6tv7pf
0MNv4J0f8Tyo3dlbdPHrGHb38WV3wv4BPnY5Yg==
          "]], 
         Line3DBox[CompressedData["
1:eJwVzT8ohHEcx/Gv5bDcTcp6g+UMyihFJgvlusVNPAOdRC4DhiuyMChM/iyk
3D0mykixsFFKlEkZdKtJiZfh3ef7e7/refLJfHGuJSISrGciTvDZGlHAVXtE
Xy6ixl20RZzjjc+jrvVqS1rKN/DAd3Oddlevasf8EW65Li1na9qsts/vIc1G
XPIZVLQpbYffxqlW53+4kjZhX7hNbQMH2hc3oJXtk7bGr2JLa3IFLevfJfcK
v/zftXfvDi2jjbqr/AIWtV/feeVCH7YzfAXT2rf2yDW9h2xiJ3HIl/U77tm7
35btBz9uR7Rr7sbdY+/5onsMg1rKneEPmyg3Pg==
          "]], 
         Line3DBox[CompressedData["
1:eJwVzT0oxHEcx/HvLY7FmZSRwXKLXYpMFgo3ncVR5HE4BlFXHibKcCfJbc5w
ORMZKRYjpZSyUApXJpOSl+Hd5/d7v/8P7bnF4YVEROSw1RBxjI9kRBqXTRHd
qYgCd94YcYZnvgMHzRFVfUWr8Se449uwr5W0vFbhj3DDd/pWiy1o81qZP/x/
1/MXfBIz2pRW4r/4oq3yv1xGG7c73Ke2bcvaN9erZe0Dv8lvYFerc2kt5d8Z
5zV+Fevaq/ue51v1IeclPo9l7cm9qCW0Aec5fhbT2g9/z9Xd++2kfecmbFa/
5R6de+yYfdOydlC74q6du+yofdFGbJ9W407xB46xOWk=
          "]], 
         Line3DBox[CompressedData["
1:eJwV0L8rxHEcx/G3xc9isWPzB7iRScpNIiYcV8pyZ3CWK2XxMyQdSe5CMWHw
Y5IMiGK93Y/BoliYDB6GZ6/v5/n89P3WtyU90ZutiIhRzFVGHOKzKuK2JuIG
7Q0RM9w+LqojXrUz/r4+4tTm+V0ca2WtxN1pRZvjSzjQHrRW71rkF5Dld1DU
jty/1HP8JMb5bXzxG/qJluKHkea38KGtaHtaku/GIF/mN+2sVtASfBsafXuA
L2Bam9ea+Wv3m2wPv44pLa/VcVdarU3ya8hoGe2X//H8jU5+FWOeR7QX+4wO
bhnv7g4592lP9hEJfglvWr9zl3b+/3/xBw1EOmE=
          "]], 
         Line3DBox[{1671, 1703, 2032, 1487, 3902, 1665, 983, 2019, 1454, 3894,
           1659, 970, 2006, 3887, 1415, 1653, 957, 1993, 3881, 1376, 1647, 
          944, 3757, 1980, 1337, 1641, 931, 3752, 1967, 1298, 1635, 3801, 918,
           1954, 1259, 1629, 3798, 905, 1941, 1220, 3861, 1623, 892, 1928, 
          1181, 3850, 1617, 879, 1915, 3843, 1142, 1611, 866, 1902, 3837, 
          1103, 1605, 853, 3741, 1889, 1064, 1599, 840, 1876, 1025, 1590, 
          3785, 826, 1863, 1718, 1719}], Line3DBox[CompressedData["
1:eJwVz6tLQ2Ech/GfCF5gaNIoLAn+ATNqEkHTwEuaOkTBsFmcZSgYvAUtchSD
C4Ka1CBegk2LsOqiIIYVw0mCQfwsPHzf93nOdjjZYjlfaouIBex2RFwh7YzI
4bU7YqQ3Yot76Iq4xxc/iNOeiDu9qt3w12jwAzjRalpFu+Qv8MYP+a8+u6+t
ajX+rPVbzz/zGaxpK9oxn/KJveXbMa8taofct3Zgz/lfbkIr2Aa/w28j0VIu
p/V796zzJr+BPa3pnng+q+ed1/kKqtqH+5GW0Sady3wJZe2Pf+d+3Mfssl1q
fQtf1Ovcp/uonbNNvmCntBeu7jxsZ+w0xvlH9yf8AxFeORs=
          "]]}, 
        {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwVzVkug3EYhfHXjZhiCagad2GmZqXKlYTEJZug5nme1sGFBeg2WIG2ZhK/
Xjw5533OP9+XWFxNr1RExALy1RFrdRHrGK2NaJBblRGvNRE5fQNjfKY+4gld
fAGb5XcYtz3zjXo3X8S2voMcP2Fv0nv4Enb1Ar+ESVvC3cu/YU8v8vtyytYs
+/h33PMH7kOkbUnZz3/gSD/GNN9S/pe3L/i0nbhPMWNrlXl+gP/CmfscGVu2
KmKQ+8YFd4lZvk0OcT+40h+9y/Lteor7xbVe8t0bOWfrkMP8Hx74W/cd5m2d
coRfxj/aTDbe
          "]], 
         Line3DBox[{2506, 1529, 2906, 832, 3812, 2814, 1005, 2907, 3813, 833, 
          2815, 1008, 2908, 3814, 834, 2816, 1011, 3719, 2909, 835, 2817, 
          1014, 3720, 2910, 836, 2818, 1017, 2911, 837, 2819, 3769, 1020, 
          2912, 838, 2820, 1023, 2913, 839, 3815, 2821, 1026, 2914, 840, 2822,
           1029, 2915, 3816, 841, 2823, 1032, 2916, 842, 2824, 1035, 3721, 
          2917, 843, 2825, 1038, 2918, 844, 2826, 3770, 1040, 2919, 1503, 
          3602}], Line3DBox[CompressedData["
1:eJwNzckugwEYheHPDq0a2rJla1bzvHIDFliKRFTxt0pEREQs3QJqnq7BJbgI
axegLD2Lk/O+5/uHno3yctIQEevy2RTRnYnYao4opiJ60xFXfEVSvMaLbiW8
aruWPlua3+ptt138be/nA9LC7/SS7VISPsiHJIPv9Y+95N0KH+Yj0oofdN1t
x63KC3xU2vBXo3/ZD/GYbVza8aPesx/hCbzpuQ78hBP7MZ7EN747pbP8WZfd
TvCavSbTthx/0RW3UzyDZyWPX/Wv5/bdzvgcn5dO/Kb/3Kpu53yBL0oX/rC/
4wO3C57jecnKP6hhK6I=
          "]], Line3DBox[CompressedData["
1:eJwNytVNAwAURuHLCwkSdihTMAcbQJAQAg2BUtpSSiluK6BPuLssgBYfBQ3f
w5+Te85NNCcbuysiosk+qiLq6yLmqyNKNRFzuOput3ftujZilitqM7jCX3Fv
2iVOcwVtCpe1C+5VO8dJLq9N4Jn7hT/FP3/jXE4bwxPuWTvGX22Uy2glPOKe
tDb+x0a4tFbEQ62sHeCwO8UXcMlfqz1q+9oQ16vlcZHf4x60XRzkerQcLmg7
3L22jVkuqZUrI7bcd/wmfvvLaF3aAG5wt9o6fmlprlPrxzXuRmvhPy3FdWh9
2OBO2D/3F0H5
          "]], Line3DBox[CompressedData["
1:eJwNzNVRA1AQQNEN8oEM1MBAEzSAfVJCCoAm0CBJSHCXUAXM4O7uLmXA+di5
b+/deTXJ9ta2REQkzW9ZRF1VRKE8IlsRsYT3lRGl1RE/2p33IpfRFnDZ7S33
rd3gPJfWSty3aNfcl3aFc9qgNouX9k/+Apvd5c2ANqOdcx/aGRb7Z5rr16bw
lHvXVt2feE9yfdoEHtvftCMct6f4MTy0F/nnVTvwHuV6tREs+Gefe9H2cJjr
0RLum7Rd7lnbwbzWrYXWqG1zT9oWNthzpkvPudvkHrUN/OOHuE4ti+vcg7bC
r3lnuA4tjfVcrfkH5YVDzg==
          "]], Line3DBox[CompressedData["
1:eJwVz0dSAmEQQOHGAA4z6hlcqHfQW3gEVq70LubsTXSvNzBnQUCJ5vTN4tXr
+V9XF0xUFucWChFRQT+JmBqLmMZ+GpGNRqTIxiN6WmIuY08b4WN7Je5qw1zE
rpbaHzIPoqMVeAA7WvBfFtH2/sO/WHNnW/s2f6GlfXDZnU/e0t75DS/aof2+
+RWbWo+7eNba3MGG91a+j8SdptbMd7CuNfjInTo3tBo/5b8l/2/2q+ZH1LV7
fsCqVtLuzLf5vnbNN3lza0W/Ml+ipl1w0f68tqyd+z5DVTvwdmI+xZI263sG
k/gHoRVFRg==
          "]], Line3DBox[CompressedData["
1:eJwV0Mcyg2EYxfHHUp8wk0KCYBgs2LBgI3qLEjXssicL4yrci97dhXoptn7f
4sxzzvk/7/uVYq1eOWuIiBr9NUaMtEWM0lVzxGxLxAe/0RSRlVOtER10zVf1
n1TGcnJan6Eb/lj/RZtYl5zXF+hSdyuX3LuFdfNFfao94hS7k+ewbSzPDyXP
w4bNe3ke28EKfN1+JzaGPcgLWAXr4cd1E/TIL+q/7e5ivfKkfoqe+CXsB9vD
+uRp/Qw98yf6X9rHism/0JfohV927kDfn9yffLf3OLf7Kq9gh9gAv4ZlsXXz
TV7FjrBB/sJ+Ditj73JGrmJp8x/EVyer
          "]], Line3DBox[CompressedData["
1:eJwV0EdKg2EURuEbdaLyJwETsYBdiCYKFlAhKqhYwJFLyMxCLLgge3cn1s2I
XZ8MDud/7/kgkN7K7kY1FREVNDRFFNMRJdw3R6wnEa++D1GvrdpruNNW+MV9
meu0RV7CrXbg/owFO6XN8TxutFkuI9xnuDUTse/ttTZtT+GvMWKC89okX2nj
PIZfbc/7nDZqX2ojXMKPNsTDuHAv8JO3VXxrA/YgzrV+fnTv4y+tm3twpu24
P6DL/tQ6uBOnWtbvtvtuw4eW54zbtvcnes5uwbuW5bS2pR1rmdrGm7bplmiJ
fVT7X+wyCvgHnbIqZQ==
          "]], Line3DBox[CompressedData["
1:eJwVzzdWw1AYROGfgobYEioKMhhYA1QkYxkTnC3b0MFGgBURbDI7gC0Q9sCn
Ys6buffpSJpJL5OLgYhIZXAoYnUsIie3wxHbIxGb+rfM2vujEXm506vYp5Q9
M2cf4AW513/wHc9WuHk7wYtyhT/Yu1yVW9AP8ZJccz17j6txi/oRPjUecezs
Z+/n6tyS3nP/BD+VRzvPNbhlvYxV5Cn7LnzL3V9Zyb4br8mzXuC+8Gb233Yd
b8iL/ocnfIvL2U28Ja96EU/xNT3F2nLj/lv2P1ybW9c7+LTv7zrf7RLX4Tb0
vvtn+Ll82JN2l5tw/gPK6S8k
          "]], Line3DBox[CompressedData["
1:eJwVz7dRA1EYReGfhACbgwiogBm8bwBIFOCtcELI4PoAmkDCUwNkeE8XmA74
Nriz957z9s1ua6aULlZFREaqayLaGiKOPG9rI8brIibkG2u3s/URZe5On8PK
Msl32BtchbvXf/ApfFo67Rw3gu3Lgz2Dz0qXvsmN4gfymNyLz0u3nudSjRHH
7n2yF/BF6dGvnS/wJ9yzvYRnpFcv4qf4i76Mrciv8312iTvjXvVVvIKvefbb
W9w596b/4et4Vgbsbe6Ce0/+FcvJoL6Djzl7KB/J/+B5GdJ3uRbff+m9T7uA
F2VYv3F+j7/ivuxmOyVN8g8i+DW2
          "]], Line3DBox[CompressedData["
1:eJwV0FdKA2EYheHPK8G6AhOjG3AH9g5euABLFmBsMUYTY9mBu7CCve9DRERE
REREXIHPf/Ey55x35p9hcvnC5FxdRORR3xDR1RJx4vrYGFFoitjTp9CtF5sj
Trknedq2j3n39Ogr3Bn3LM/YD7DA9eolbkLfxYu+aF9Cn7zKZVojzj37qi/b
i+iXy1yWu+De0jvsJQyk7Kx27pJ7T+fYyxiU1zx3Zf9I2Xbo3lkM6evcNfeZ
Mndkr7gO6xXuhvuS8/ZjVLkRvcrdct/yhq2G0ZTtOd9xx/3om/YtjMk1roO7
5371bfsOxtM/cXYn98D96Rk9izb8AyUwOD0=
          "]], Line3DBox[CompressedData["

1:eJwNzcdJhFEYRuHPnc44M8YCBPNOC7AFwRKmAGdr2JhzDnUY1+acc0BERERE
RMQGfBaX895zfu5fkc21tOZFRNYpT0Q0piMe8C8ZcY+r7p1OmT2firjDX+0W
V/g5rtSexRv80a5xWZvhSuxpvMJv7RKn3ItxEuszERf2l3aOE1wRjmOddmZ/
aqc4xmWww9u12on9oR3jqJbGETzCd/4Ql3zb7qTsYe0A37R9XOSHuEJ7EPfw
VdvFBW2AS9r9uIMvWo3/Nmt9XILrxWpu237Wt7CHK8BurNI27SdtA7u4fGzz
RqW2bj9qa9jENTj/zoA9VA==
          "]], Line3DBox[CompressedData["
1:eJwNzDVWAwAQRdFJi3a4BUr8QJ8tQGAFWQDshgR3twpWAIvA3a3B/RZz3p/3
50wy05/uS0RExjTkRXQWRTxhoiDiEdcLI9qLI+rlNfkBQ3ePm25XuaS8gnf4
lx/R5r5Xt8zVcUt4i7+6G1y01+IC9rjLmR/dNTfP1eActvpzJX/rLnGWq8Zt
9zPyhfylO8dpexVO4Rl+8qc4aW/xp1KekE/wQ3eMG/6McxXyGB7hu67ZfVo3
ypVzI3iIb7omXbdumCvjhrDLnjWv+gNukCvFHDa635dfdHuY5Upwy/2AvCs/
63YwxXWYfyEBQIc=
          "]], Line3DBox[CompressedData["
1:eJwVzNVRA1AQQNHFIURqYAZ3Akn4hBYoIQVAAzQCVeDuEtw9wSvh8HHn7nt3
Z1uKUxOTVRFRxFAiIp+OKCCTjPhNRfxgNBMxqH2Zv5HWPrli74MHtAq/I6UV
7JfNb+jXXvgVSe2Zn9Dn/4EfMetOs3ZvvkOvdsN5d245oV3zFXq0E/sX5ks0
aed8hu7/xqdo9F/iY+Tc6dIOzUdo0A647M4+d2q7vId6bcT+jnkbHdomb6FO
G9Y2zOto11Z5DTNu1eor5mW0aUuctT+t1WiL3gto1Ur+5szzqNbGvceQwx9q
djlO
          "]], Line3DBox[CompressedData["
1:eJwV0FdOgmEUBuGDDUWavV+4BRSVouzBJbAAXYFdd2mNvWPv5eFiMrxn/uRL
mKwvLy4lIqKOWioin43owUQ6IsdH2MGCluEsxrU0H6Ib81oXpzCmbfMBOlHV
OjiJUa2d21Bxb+VaLmKLR7QWTqCs/WW8qYU9rP3aPyhpm803tW97SPviT8xp
7/yBQfc33vftBma1F/sVA9oz77k/8Yz2wI/o19bdd9Gwi9od36NPq3r31u8b
TGvXXHFb832vfmVfYkq74LK22vxPtXP7DAVtxa2kndp57YSP0dD+AfQBM5A=

          "]]}}},
      VertexNormals->CompressedData["
1:eJztXXl8DWfbPoJQlKItShuqSJRaqyra4KWIBFlI7GmDRBJ98ZYiVNSWiEqo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       "]], {}}, 
    {RGBColor[0, 0, 1], PointSize[0.025], Point3DBox[{1, 0, 0.5}]}, 
    {RGBColor[0, 0, 1], PointSize[0.025], Point3DBox[{0, 1, 1.5}]}},
   Axes->True,
   BaseStyle->{FontFamily -> "Arial"},
   DisplayFunction->Identity,
   FaceGridsStyle->Automatic,
   ImagePadding->Automatic,
   ImageSize->{346.9492110897955, 343.87693461712007`},
   ImageSizeRaw->Automatic,
   Method->{
    "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}},
   PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}, {
     Automatic, Automatic}},
   PlotRangePadding->{{
      Scaled[0.05], 
      Scaled[0.05]}, {
      Scaled[0.05], 
      Scaled[0.05]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic, Automatic},
   ViewPoint->
    NCache[{Pi, Rational[1, 2] Pi, 2}, {
     3.141592653589793, 1.5707963267948966`, 2}],
   ViewVertical->{0.3814429589423475, 0.17545599386132063`, 
    0.907588267493274}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.861423817490148*^9, 3.861423825496559*^9}, 
   3.861423974011313*^9, {3.861424005353634*^9, 3.86142404212757*^9}, {
   3.861424238129505*^9, 3.8614242533607616`*^9}, {3.861424490088573*^9, 
   3.861424503650113*^9}, 3.861436091563242*^9, 3.8614363370211763`*^9, 
   3.8614367528297358`*^9, 3.861436792863463*^9, {3.8614369122365847`*^9, 
   3.861436923588087*^9}, 3.861436970548789*^9, 3.861437048565228*^9, 
   3.86143722454843*^9, 3.8615241976495247`*^9, 3.861633593158258*^9, 
   3.861633699913362*^9, 3.861633961581182*^9, 3.861634027677814*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"c54bd5cd-11b9-4d8e-836d-507245568a40"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Geodesic between the Points", "Section",
 CellChangeTimes->{{3.861424094607534*^9, 
  3.86142410482253*^9}},ExpressionUUID->"975c8d97-dba0-46b3-8f44-\
d444d875f7b3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"For", " ", "the", " ", "geodesic"}], ",", " ", 
    RowBox[{
     RowBox[{
     "we", " ", "now", " ", "have", " ", "to", " ", "use", " ", "the", " ", 
      "constants", " ", "c1", " ", "and", " ", "c2", " ", "found", " ", 
      "from", " ", "the", " ", "conditions", " ", "z", 
      RowBox[{"(", "\[Phi]1", ")"}]}], "=", 
     RowBox[{
      RowBox[{"z1", " ", "and", " ", "z", 
       RowBox[{"(", "\[Phi]2", ")"}]}], "=", 
      RowBox[{"z2", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"see", " ", "the", " ", "text", " ", "above"}], ")"}], 
        "."}]}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "\[Phi]_", "]"}], ":=", 
     RowBox[{
      RowBox[{"c1", "*", "\[Phi]"}], "+", "c2"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"c1", "=", 
     FractionBox["2", "\[Pi]"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"c2", "=", "0.5"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8614241062175627`*^9, 3.861424109862636*^9}, {
   3.8614244021387243`*^9, 3.861424465874796*^9}, {3.8614361231276693`*^9, 
   3.861436124724409*^9}, 3.861436249273741*^9, {3.861436725570472*^9, 
   3.861436728075944*^9}, {3.8614674161330767`*^9, 3.861467420020296*^9}, 
   3.861633567323923*^9, {3.861633667749666*^9, 3.8616336785234003`*^9}, {
   3.86163386267905*^9, 3.861633871174665*^9}, {3.861634016153859*^9, 
   3.861634018044376*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"d9b7068a-61aa-48d6-8d82-c6780559f3ea"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Plot", " ", "the", " ", 
    RowBox[{"geodesic", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"geodesic", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"rCyl", ",", "\[Phi]"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"rCyl", ",", "\[Phi]"}], "]"}], ",", 
       RowBox[{"z", "[", "\[Phi]", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Phi]", ",", "\[Phi]1", ",", "\[Phi]2"}], "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\[Pi]", ",", 
        RowBox[{"\[Pi]", "/", "2"}], ",", "2"}], "}"}]}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8614245096735153`*^9, 3.8614246302982073`*^9}, {
  3.861424821287554*^9, 3.8614248332250643`*^9}, {3.861424866553084*^9, 
  3.86142486949955*^9}, {3.861425482891651*^9, 3.861425503799552*^9}, {
  3.861435530548292*^9, 3.861435552652109*^9}, {3.8614356712201157`*^9, 
  3.8614356731829243`*^9}, {3.861435716490395*^9, 3.86143581184837*^9}, {
  3.861435890328966*^9, 3.8614359192055273`*^9}, {3.8614361449222403`*^9, 
  3.861436150586879*^9}, {3.861436731939147*^9, 3.86143673609739*^9}, {
  3.861437037073697*^9, 3.861437038628744*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"de29bbb0-7d6e-47a0-b289-784398a7dc5f"],

Cell[BoxData[
 FormBox[
  Graphics3DBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
       Line3DBox[CompressedData["
1:eJw11nk0Vfv7B3BRKVQyRZRS1K1cmZoM70iKJtxQiFBkKNElJAelNJgrJZUp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        "]]},
      Annotation[#, "Charting`Private`Tag$1255#1"]& ]}, {}},
   Axes->True,
   BaseStyle->{FontFamily -> "Arial"},
   DisplayFunction->Identity,
   FaceGridsStyle->Automatic,
   ImagePadding->Automatic,
   Method->{
    "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}},
   PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}, {
     Automatic, Automatic}},
   PlotRangePadding->{{
      Scaled[0.05], 
      Scaled[0.05]}, {
      Scaled[0.05], 
      Scaled[0.05]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic, Automatic},
   ViewPoint->
    NCache[{Pi, Rational[1, 2] Pi, 2}, {
     3.141592653589793, 1.5707963267948966`, 2}]], TraditionalForm]], "Output",\

 CellChangeTimes->{{3.861424558442491*^9, 3.861424630508965*^9}, 
   3.861424833801817*^9, 3.861424869878161*^9, {3.861425490406431*^9, 
   3.861425510661026*^9}, {3.8614355382495003`*^9, 3.861435558981935*^9}, 
   3.8614356736144238`*^9, {3.86143572566122*^9, 3.861435812129805*^9}, {
   3.861435891183751*^9, 3.861435919880877*^9}, {3.861436126122609*^9, 
   3.861436150873412*^9}, 3.861436300970777*^9, 3.8614363412586393`*^9, 
   3.861436752950108*^9, 3.861436792980466*^9, 3.861437048808444*^9, 
   3.861437224623798*^9, 3.861524197876895*^9, 3.861633593640657*^9, 
   3.861633700420594*^9, 3.861633963119227*^9, 3.861634027942745*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"933d8f39-4c7c-45ae-9707-395b6cc3cde0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Combined Plot of Everything", "Section",
 CellChangeTimes->{{3.8614675122842712`*^9, 
  3.861467525769026*^9}},ExpressionUUID->"c98efa5d-ff9d-49e3-ac68-\
2076ea961c2b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Combine", " ", "the", " ", "cylinder", " ", "with", " ", "the", " ", 
    "two", " ", "points", " ", "and", " ", "their", " ", 
    RowBox[{"geodesic", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Show", "[", 
   RowBox[{"Cyl", ",", "p1Plot", ",", "p2Plot", ",", "geodesic", ",", 
    RowBox[{"ViewPoint", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\[Pi]", ",", 
       RowBox[{"\[Pi]", "/", "2"}], ",", "2"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.861424609832774*^9, 3.8614246316625977`*^9}, {
  3.8614248383466*^9, 3.861424840610106*^9}, {3.861436738913888*^9, 
  3.861436740273699*^9}, {3.861436991396061*^9, 3.861436991690984*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"412efb08-62e7-419f-9924-418eaa5f98d9"],

Cell[BoxData[
 FormBox[
  Graphics3DBox[{{GraphicsComplex3DBox[CompressedData["
1:eJyVnXmcntPZgMfSEFtEokFVkbFUJEg0tshY2tQImiqtSqjP8hEMat9VqVaL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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[2], 
         EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[
           TagBox[{Polygon3DBox[CompressedData["
1:eJxFnXXcFcUXxve9u3vv9iuYYACKIArY3d3dDWJ3d3cHBnaLia3YhagodmNi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              "]], 
             Polygon3DBox[CompressedData["
1:eJwtnXkcFeMXxmfuPvfOvUVkpyikJFJIi0JFCoUQUURSIbtEKaUoS5QSsrVo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              "]], 
             Polygon3DBox[CompressedData["
1:eJwl1nmUT2UcBvBbg/mNH8maQUk5lS1SlvaTLNnH2JVlxjIihKKMpWxFm+XQ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              "]]},
            Annotation[#, "Charting`Private`Tag$1179#1"]& ]],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {{}, {}, {}, 
        {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwNzbErxHEch/EPV+7OgLO4GCRi+f2K2Fj8NpMysFjYRGxmUhSKFJt/4BQj
G3ILGxYiE5PuNiyK1/Du+X6eZ/j2zK9MLTdExJwNNUWcWpaPOMPNloiLQsSX
+wavuEnva9zSqtyv+wlvuVnvO9zWnrmc1eyBW9Aese5utsaiD1sjXrhV7RVz
XEnrwLz2zm1oH1jmylqCbVqN29fquOO/lO/Wx/GbO9Z+cFfLuH5tGv+4iha2
p81wqbaIBe7cinagLXEj2hoO+LPEV63d1rlR7RATrZO7ty474jKtgsNaL/dm
fXbCTWiXOKYl3KelNmj/ZxwyJw==
          "]], Line3DBox[CompressedData["
1:eJwVzb0vw2EUhuFT8VGaEB9LBWHApE0aNltNJjExWDpK1GjHYJEwMfEHINjY
hNSik7D43FgkbSSEQeL6DU+ec+775H2HSsuz5VRElKTQHHEixZaIU32ejvhs
j/i2V8yX2Iz5Sm/g19if/UHfYAvmL7xqfsQapSZ39n18kb8317FM4lsjUh0R
z9gK96KbsC4uq9PcG7bOveteLMtVvZUz17Btrq7z9k73g3zR/IPtcb960/0U
NsrNJX/iB9IgW9w8luOWdBt2JgPeyugyNsGt6m77sfuK7pE1bJLb0WPu+7Bb
6ZddrMgd6nFuGHuVETnCprknb10kf2MfkpeC/AO6/DQx
          "]], 
         Line3DBox[{1587, 1714, 1860, 993, 3827, 2039, 1015, 1873, 1017, 2046,
           1054, 1886, 3830, 1056, 2053, 1093, 3744, 1899, 1095, 2060, 1132, 
          3749, 1912, 1134, 2067, 3786, 1171, 1925, 1173, 2074, 3789, 1210, 
          1938, 1212, 3858, 2081, 1249, 1951, 1251, 3866, 2088, 1288, 1964, 
          3868, 1290, 2095, 1327, 1977, 3871, 1329, 2102, 1366, 3760, 1990, 
          1368, 2109, 1405, 3765, 2003, 1407, 2116, 3802, 1444, 2016, 1446, 
          2123, 3805, 1480, 2029, 1841, 1844}], Line3DBox[CompressedData["
1:eJwV0DkvRGEUgOFDMTO3QEE3CDqNjGWi010UqiktEWox6PSWH6CyFPwAy0Qh
RoNmUKiUlvgDEkuh47nFm/d8eU++fPf2LlYry00RsYCRXMQ50nzEVSHiojWi
zr/ODb5DxfzAl9o9/zk/8wvmzW/8ihw+8YUju0vaj/kbLVlPIprbIvK8riVc
QIdW5ETr5C2tm7tQ1B7dVTIPYkcb5iG02+/TU/M4DrVJvrY/wf3aNM/gWJvj
W22WS1qVV1DXety1Zl7FqLbBm6jZb+jb2bswpu3ygP09ftIOeB+pdsJl7ZTf
tRqfYSr7R+66yd6Aj+w7UMY/xy4zvg==
          "]], 
         Line3DBox[{8, 460, 2807, 23, 473, 2820, 38, 486, 2833, 53, 2514, 499,
           68, 2528, 512, 83, 2542, 525, 98, 2557, 538, 2846, 113, 551, 2859, 
          128, 564, 2872, 143, 577, 2885, 158, 2574, 590, 173, 2588, 603, 188,
           2602, 616, 203, 2616, 629, 218}], 
         Line3DBox[{247, 246, 2902, 646, 265, 2916, 660, 279, 2940, 674, 2941,
           293, 688, 2958, 307, 702, 2972, 321, 716, 2986, 335, 3000, 730, 
          349, 3014, 744, 363, 3028, 758, 377, 3052, 772, 3053, 391, 786, 
          3070, 405, 800, 3084, 419, 814, 3098, 443, 446}], 
         Line3DBox[CompressedData["
1:eJwVzz8vQ3EUxvEjQTXSa6KLpKoLJqbeWGwSiS4Ge2vHxOQF+BOJyYp4AyQM
iE0XSTuyIRgYa6Bh8LnDk+ec7/fkd3PLjbWl1Z6IqEvaH3ElC7mIa30zENE1
t/Sdfdnc1NtJRBsLeZUWtsJ9Z9z8huXkRx7sJ/g6/2juYokU8hG9QxHP2Bb3
ohNsmBvXg9wHtsN96go2yrW9VTV3sEPuS6f2ovsKv2j+xU65P73vvoZNcfXs
m/iZ9MkB18BmuA1dwG6l7K1Eb2Ipt6tH7Ofu73VR9rA57khPuy9l/ydjcozN
cxe6yk1g7zIpl1iNe/JWM/NYR1KZlX9kLjQv
          "]], 
         Line3DBox[{1593, 1724, 1866, 1000, 3828, 2042, 1036, 1879, 1038, 
          2049, 1075, 1892, 3832, 1077, 2056, 1114, 3747, 1905, 1116, 2063, 
          1153, 3750, 1918, 1155, 2070, 3787, 1192, 1931, 1194, 2077, 3792, 
          1231, 1944, 1233, 3864, 2084, 1270, 1957, 1272, 3867, 2091, 1309, 
          1970, 3869, 1311, 2098, 1348, 1983, 3874, 1350, 2105, 1387, 3763, 
          1996, 1389, 2112, 1426, 3766, 2009, 1428, 2119, 3803, 1465, 2022, 
          1467, 2126, 3808, 1494, 2035, 1849, 1852}], 
         Line3DBox[CompressedData["
1:eJwVzjkvRGEUgOFDYplEDBrRTCK2RiMaZkyhk0xiq9TDKElUlsIfsLVahj9A
YowQoqCRWDqdgvEDVJbEc4s37/nue+53b3dxeXapLiKKyDZGXKLQFHHVHFFp
deYf50d+wpz5havaM9fjHR8oaZ98odU4he/kfZQ9W9H/zL9oQzoV0ZA286bW
we3o1Hq5RevjLW2A+5FJ/sNdo+Ys9rUxzqEr2dcnzVM41mb4xv40D2rzvIAT
bZFvtRIPa6u8hmutx10b5vXkO9o27+DU/oO+Z97FuHbAQ/YP+VU74jImtDMe
0Spc06p8nvyf9uauO/M9vrQc8vgHlnE2Cw==
          "]], Line3DBox[CompressedData["

1:eJwVzb0rxAEcx/GvxcOAgX9AGVjskpPJQulucZOjcKU8ZGCgriykiyN5uISU
c5vB5vJQMhrEZDVwg92Cl+Hd5/t7v3/9fm3js8mZmogYw2ptxBk+6iIqDRHX
6G6OWOFOcVkf8aaV+MemiHO7yB/jQnvStrkHrWDn+SOcaPda+/+3+GVM80Xs
a2XvX+lZfgoT/AG++C29pKX4JEb5PVS1Ne1QS/C9SPPP/K7NaXmtk+9Ao3+n
+B0saTmtlb/xfosd4guY0xa0X1vRfuwAv4mse1L75qvuT/TzeWTcRT6tv7pf
0MNv4J0f8Tyo3dlbdPHrGHb38WV3wv4BPnY5Yg==
          "]], 
         Line3DBox[CompressedData["
1:eJwVzT8ohHEcx/Gv5bDcTcp6g+UMyihFJgvlusVNPAOdRC4DhiuyMChM/iyk
3D0mykixsFFKlEkZdKtJiZfh3ef7e7/refLJfHGuJSISrGciTvDZGlHAVXtE
Xy6ixl20RZzjjc+jrvVqS1rKN/DAd3Oddlevasf8EW65Li1na9qsts/vIc1G
XPIZVLQpbYffxqlW53+4kjZhX7hNbQMH2hc3oJXtk7bGr2JLa3IFLevfJfcK
v/zftXfvDi2jjbqr/AIWtV/feeVCH7YzfAXT2rf2yDW9h2xiJ3HIl/U77tm7
35btBz9uR7Rr7sbdY+/5onsMg1rKneEPmyg3Pg==
          "]], 
         Line3DBox[CompressedData["
1:eJwVzT0oxHEcx/HvLY7FmZSRwXKLXYpMFgo3ncVR5HE4BlFXHibKcCfJbc5w
ORMZKRYjpZSyUApXJpOSl+Hd5/d7v/8P7bnF4YVEROSw1RBxjI9kRBqXTRHd
qYgCd94YcYZnvgMHzRFVfUWr8Se449uwr5W0vFbhj3DDd/pWiy1o81qZP/x/
1/MXfBIz2pRW4r/4oq3yv1xGG7c73Ke2bcvaN9erZe0Dv8lvYFerc2kt5d8Z
5zV+Fevaq/ue51v1IeclPo9l7cm9qCW0Aec5fhbT2g9/z9Xd++2kfecmbFa/
5R6de+yYfdOydlC74q6du+yofdFGbJ9W407xB46xOWk=
          "]], 
         Line3DBox[CompressedData["
1:eJwV0L8rxHEcx/G3xc9isWPzB7iRScpNIiYcV8pyZ3CWK2XxMyQdSe5CMWHw
Y5IMiGK93Y/BoliYDB6GZ6/v5/n89P3WtyU90ZutiIhRzFVGHOKzKuK2JuIG
7Q0RM9w+LqojXrUz/r4+4tTm+V0ca2WtxN1pRZvjSzjQHrRW71rkF5Dld1DU
jty/1HP8JMb5bXzxG/qJluKHkea38KGtaHtaku/GIF/mN+2sVtASfBsafXuA
L2Bam9ea+Wv3m2wPv44pLa/VcVdarU3ya8hoGe2X//H8jU5+FWOeR7QX+4wO
bhnv7g4592lP9hEJfglvWr9zl3b+/3/xBw1EOmE=
          "]], 
         Line3DBox[{1671, 1703, 2032, 1487, 3902, 1665, 983, 2019, 1454, 3894,
           1659, 970, 2006, 3887, 1415, 1653, 957, 1993, 3881, 1376, 1647, 
          944, 3757, 1980, 1337, 1641, 931, 3752, 1967, 1298, 1635, 3801, 918,
           1954, 1259, 1629, 3798, 905, 1941, 1220, 3861, 1623, 892, 1928, 
          1181, 3850, 1617, 879, 1915, 3843, 1142, 1611, 866, 1902, 3837, 
          1103, 1605, 853, 3741, 1889, 1064, 1599, 840, 1876, 1025, 1590, 
          3785, 826, 1863, 1718, 1719}], Line3DBox[CompressedData["
1:eJwVz6tLQ2Ech/GfCF5gaNIoLAn+ATNqEkHTwEuaOkTBsFmcZSgYvAUtchSD
C4Ka1CBegk2LsOqiIIYVw0mCQfwsPHzf93nOdjjZYjlfaouIBex2RFwh7YzI
4bU7YqQ3Yot76Iq4xxc/iNOeiDu9qt3w12jwAzjRalpFu+Qv8MYP+a8+u6+t
ajX+rPVbzz/zGaxpK9oxn/KJveXbMa8taofct3Zgz/lfbkIr2Aa/w28j0VIu
p/V796zzJr+BPa3pnng+q+ed1/kKqtqH+5GW0Sady3wJZe2Pf+d+3Mfssl1q
fQtf1Ovcp/uonbNNvmCntBeu7jxsZ+w0xvlH9yf8AxFeORs=
          "]]}, 
        {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwVzVkug3EYhfHXjZhiCagad2GmZqXKlYTEJZug5nme1sGFBeg2WIG2ZhK/
Xjw5533OP9+XWFxNr1RExALy1RFrdRHrGK2NaJBblRGvNRE5fQNjfKY+4gld
fAGb5XcYtz3zjXo3X8S2voMcP2Fv0nv4Enb1Ar+ESVvC3cu/YU8v8vtyytYs
+/h33PMH7kOkbUnZz3/gSD/GNN9S/pe3L/i0nbhPMWNrlXl+gP/CmfscGVu2
KmKQ+8YFd4lZvk0OcT+40h+9y/Lteor7xbVe8t0bOWfrkMP8Hx74W/cd5m2d
coRfxj/aTDbe
          "]], 
         Line3DBox[{2506, 1529, 2906, 832, 3812, 2814, 1005, 2907, 3813, 833, 
          2815, 1008, 2908, 3814, 834, 2816, 1011, 3719, 2909, 835, 2817, 
          1014, 3720, 2910, 836, 2818, 1017, 2911, 837, 2819, 3769, 1020, 
          2912, 838, 2820, 1023, 2913, 839, 3815, 2821, 1026, 2914, 840, 2822,
           1029, 2915, 3816, 841, 2823, 1032, 2916, 842, 2824, 1035, 3721, 
          2917, 843, 2825, 1038, 2918, 844, 2826, 3770, 1040, 2919, 1503, 
          3602}], Line3DBox[CompressedData["
1:eJwNzckugwEYheHPDq0a2rJla1bzvHIDFliKRFTxt0pEREQs3QJqnq7BJbgI
axegLD2Lk/O+5/uHno3yctIQEevy2RTRnYnYao4opiJ60xFXfEVSvMaLbiW8
aruWPlua3+ptt138be/nA9LC7/SS7VISPsiHJIPv9Y+95N0KH+Yj0oofdN1t
x63KC3xU2vBXo3/ZD/GYbVza8aPesx/hCbzpuQ78hBP7MZ7EN747pbP8WZfd
TvCavSbTthx/0RW3UzyDZyWPX/Wv5/bdzvgcn5dO/Kb/3Kpu53yBL0oX/rC/
4wO3C57jecnKP6hhK6I=
          "]], Line3DBox[CompressedData["
1:eJwNytVNAwAURuHLCwkSdihTMAcbQJAQAg2BUtpSSiluK6BPuLssgBYfBQ3f
w5+Te85NNCcbuysiosk+qiLq6yLmqyNKNRFzuOput3ftujZilitqM7jCX3Fv
2iVOcwVtCpe1C+5VO8dJLq9N4Jn7hT/FP3/jXE4bwxPuWTvGX22Uy2glPOKe
tDb+x0a4tFbEQ62sHeCwO8UXcMlfqz1q+9oQ16vlcZHf4x60XRzkerQcLmg7
3L22jVkuqZUrI7bcd/wmfvvLaF3aAG5wt9o6fmlprlPrxzXuRmvhPy3FdWh9
2OBO2D/3F0H5
          "]], Line3DBox[CompressedData["
1:eJwNzNVRA1AQQNEN8oEM1MBAEzSAfVJCCoAm0CBJSHCXUAXM4O7uLmXA+di5
b+/deTXJ9ta2REQkzW9ZRF1VRKE8IlsRsYT3lRGl1RE/2p33IpfRFnDZ7S33
rd3gPJfWSty3aNfcl3aFc9qgNouX9k/+Apvd5c2ANqOdcx/aGRb7Z5rr16bw
lHvXVt2feE9yfdoEHtvftCMct6f4MTy0F/nnVTvwHuV6tREs+Gefe9H2cJjr
0RLum7Rd7lnbwbzWrYXWqG1zT9oWNthzpkvPudvkHrUN/OOHuE4ti+vcg7bC
r3lnuA4tjfVcrfkH5YVDzg==
          "]], Line3DBox[CompressedData["
1:eJwVz0dSAmEQQOHGAA4z6hlcqHfQW3gEVq70LubsTXSvNzBnQUCJ5vTN4tXr
+V9XF0xUFucWChFRQT+JmBqLmMZ+GpGNRqTIxiN6WmIuY08b4WN7Je5qw1zE
rpbaHzIPoqMVeAA7WvBfFtH2/sO/WHNnW/s2f6GlfXDZnU/e0t75DS/aof2+
+RWbWo+7eNba3MGG91a+j8SdptbMd7CuNfjInTo3tBo/5b8l/2/2q+ZH1LV7
fsCqVtLuzLf5vnbNN3lza0W/Ml+ipl1w0f68tqyd+z5DVTvwdmI+xZI263sG
k/gHoRVFRg==
          "]], Line3DBox[CompressedData["
1:eJwV0Mcyg2EYxfHHUp8wk0KCYBgs2LBgI3qLEjXssicL4yrci97dhXoptn7f
4sxzzvk/7/uVYq1eOWuIiBr9NUaMtEWM0lVzxGxLxAe/0RSRlVOtER10zVf1
n1TGcnJan6Eb/lj/RZtYl5zXF+hSdyuX3LuFdfNFfao94hS7k+ewbSzPDyXP
w4bNe3ke28EKfN1+JzaGPcgLWAXr4cd1E/TIL+q/7e5ivfKkfoqe+CXsB9vD
+uRp/Qw98yf6X9rHism/0JfohV927kDfn9yffLf3OLf7Kq9gh9gAv4ZlsXXz
TV7FjrBB/sJ+Ditj73JGrmJp8x/EVyer
          "]], Line3DBox[CompressedData["
1:eJwV0EdKg2EURuEbdaLyJwETsYBdiCYKFlAhKqhYwJFLyMxCLLgge3cn1s2I
XZ8MDud/7/kgkN7K7kY1FREVNDRFFNMRJdw3R6wnEa++D1GvrdpruNNW+MV9
meu0RV7CrXbg/owFO6XN8TxutFkuI9xnuDUTse/ttTZtT+GvMWKC89okX2nj
PIZfbc/7nDZqX2ojXMKPNsTDuHAv8JO3VXxrA/YgzrV+fnTv4y+tm3twpu24
P6DL/tQ6uBOnWtbvtvtuw4eW54zbtvcnes5uwbuW5bS2pR1rmdrGm7bplmiJ
fVT7X+wyCvgHnbIqZQ==
          "]], Line3DBox[CompressedData["
1:eJwVzzdWw1AYROGfgobYEioKMhhYA1QkYxkTnC3b0MFGgBURbDI7gC0Q9sCn
Ys6buffpSJpJL5OLgYhIZXAoYnUsIie3wxHbIxGb+rfM2vujEXm506vYp5Q9
M2cf4AW513/wHc9WuHk7wYtyhT/Yu1yVW9AP8ZJccz17j6txi/oRPjUecezs
Z+/n6tyS3nP/BD+VRzvPNbhlvYxV5Cn7LnzL3V9Zyb4br8mzXuC+8Gb233Yd
b8iL/ocnfIvL2U28Ja96EU/xNT3F2nLj/lv2P1ybW9c7+LTv7zrf7RLX4Tb0
vvtn+Ll82JN2l5tw/gPK6S8k
          "]], Line3DBox[CompressedData["
1:eJwVz7dRA1EYReGfhACbgwiogBm8bwBIFOCtcELI4PoAmkDCUwNkeE8XmA74
Nriz957z9s1ua6aULlZFREaqayLaGiKOPG9rI8brIibkG2u3s/URZe5On8PK
Msl32BtchbvXf/ApfFo67Rw3gu3Lgz2Dz0qXvsmN4gfymNyLz0u3nudSjRHH
7n2yF/BF6dGvnS/wJ9yzvYRnpFcv4qf4i76Mrciv8312iTvjXvVVvIKvefbb
W9w596b/4et4Vgbsbe6Ce0/+FcvJoL6Djzl7KB/J/+B5GdJ3uRbff+m9T7uA
F2VYv3F+j7/ivuxmOyVN8g8i+DW2
          "]], Line3DBox[CompressedData["
1:eJwV0FdKA2EYheHPK8G6AhOjG3AH9g5euABLFmBsMUYTY9mBu7CCve9DRERE
REREXIHPf/Ey55x35p9hcvnC5FxdRORR3xDR1RJx4vrYGFFoitjTp9CtF5sj
Trknedq2j3n39Ogr3Bn3LM/YD7DA9eolbkLfxYu+aF9Cn7zKZVojzj37qi/b
i+iXy1yWu+De0jvsJQyk7Kx27pJ7T+fYyxiU1zx3Zf9I2Xbo3lkM6evcNfeZ
Mndkr7gO6xXuhvuS8/ZjVLkRvcrdct/yhq2G0ZTtOd9xx/3om/YtjMk1roO7
5371bfsOxtM/cXYn98D96Rk9izb8AyUwOD0=
          "]], Line3DBox[CompressedData["

1:eJwNzcdJhFEYRuHPnc44M8YCBPNOC7AFwRKmAGdr2JhzDnUY1+acc0BERERE
RMQGfBaX895zfu5fkc21tOZFRNYpT0Q0piMe8C8ZcY+r7p1OmT2firjDX+0W
V/g5rtSexRv80a5xWZvhSuxpvMJv7RKn3ItxEuszERf2l3aOE1wRjmOddmZ/
aqc4xmWww9u12on9oR3jqJbGETzCd/4Ql3zb7qTsYe0A37R9XOSHuEJ7EPfw
VdvFBW2AS9r9uIMvWo3/Nmt9XILrxWpu237Wt7CHK8BurNI27SdtA7u4fGzz
RqW2bj9qa9jENTj/zoA9VA==
          "]], Line3DBox[CompressedData["
1:eJwNzDVWAwAQRdFJi3a4BUr8QJ8tQGAFWQDshgR3twpWAIvA3a3B/RZz3p/3
50wy05/uS0RExjTkRXQWRTxhoiDiEdcLI9qLI+rlNfkBQ3ePm25XuaS8gnf4
lx/R5r5Xt8zVcUt4i7+6G1y01+IC9rjLmR/dNTfP1eActvpzJX/rLnGWq8Zt
9zPyhfylO8dpexVO4Rl+8qc4aW/xp1KekE/wQ3eMG/6McxXyGB7hu67ZfVo3
ypVzI3iIb7omXbdumCvjhrDLnjWv+gNukCvFHDa635dfdHuY5Upwy/2AvCs/
63YwxXWYfyEBQIc=
          "]], Line3DBox[CompressedData["
1:eJwVzNVRA1AQQNHFIURqYAZ3Akn4hBYoIQVAAzQCVeDuEtw9wSvh8HHn7nt3
Z1uKUxOTVRFRxFAiIp+OKCCTjPhNRfxgNBMxqH2Zv5HWPrli74MHtAq/I6UV
7JfNb+jXXvgVSe2Zn9Dn/4EfMetOs3ZvvkOvdsN5d245oV3zFXq0E/sX5ks0
aed8hu7/xqdo9F/iY+Tc6dIOzUdo0A647M4+d2q7vId6bcT+jnkbHdomb6FO
G9Y2zOto11Z5DTNu1eor5mW0aUuctT+t1WiL3gto1Ur+5szzqNbGvceQwx9q
djlO
          "]], Line3DBox[CompressedData["
1:eJwV0FdOgmEUBuGDDUWavV+4BRSVouzBJbAAXYFdd2mNvWPv5eFiMrxn/uRL
mKwvLy4lIqKOWioin43owUQ6IsdH2MGCluEsxrU0H6Ib81oXpzCmbfMBOlHV
OjiJUa2d21Bxb+VaLmKLR7QWTqCs/WW8qYU9rP3aPyhpm803tW97SPviT8xp
7/yBQfc33vftBma1F/sVA9oz77k/8Yz2wI/o19bdd9Gwi9od36NPq3r31u8b
TGvXXHFb832vfmVfYkq74LK22vxPtXP7DAVtxa2kndp57YSP0dD+AfQBM5A=

          "]]}}},
      VertexNormals->CompressedData["
1:eJztXXl8DWfbPoJQlKItShuqSJRaqyra4KWIBFlI7GmDRBJ98ZYiVNSWiEqo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       "]], {}}, 
    {RGBColor[0, 0, 1], PointSize[0.025], Point3DBox[{1, 0, 0.5}]}, 
    {RGBColor[0, 0, 1], PointSize[0.025], 
     Point3DBox[{0, 1, 1.5}]}, {{{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
        Line3DBox[CompressedData["
1:eJw11nk0Vfv7B3BRKVQyRZRS1K1cmZoM70iKJtxQiFBkKNElJAelNJgrJZUp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         "]]},
       Annotation[#, "Charting`Private`Tag$1255#1"]& ]}, {}}},
   Axes->True,
   BaseStyle->{FontFamily -> "Arial"},
   DisplayFunction->Identity,
   FaceGridsStyle->Automatic,
   ImagePadding->Automatic,
   ImageSize->{318.29426011741344`, 317.4806055008816},
   ImageSizeRaw->Automatic,
   Method->{
    "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}},
   PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}, {
     Automatic, Automatic}},
   PlotRangePadding->{{
      Scaled[0.05], 
      Scaled[0.05]}, {
      Scaled[0.05], 
      Scaled[0.05]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic, Automatic},
   ViewPoint->
    NCache[{Pi, Rational[1, 2] Pi, 2}, {
     3.141592653589793, 1.5707963267948966`, 2}],
   ViewVertical->{0.12020521365843825`, 0.05768697025736244, 
    0.9910716018895182}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.861424631964075*^9, 3.861424840891107*^9, 3.861424872290189*^9, {
   3.861425494157022*^9, 3.861425512260399*^9}, {3.861435543221532*^9, 
   3.861435560777132*^9}, 3.861435680519167*^9, {3.861435734201008*^9, 
   3.861435759834916*^9}, {3.861435802034973*^9, 3.861435814409519*^9}, 
   3.8614358961243057`*^9, 3.861436152946765*^9, 3.8614363071802998`*^9, 
   3.861436342671103*^9, 3.861436753057972*^9, 3.861436793216654*^9, {
   3.86143699202209*^9, 3.86143700994458*^9}, 3.861437048868701*^9, 
   3.861437224702671*^9, 3.861524197977017*^9, 3.861633593828244*^9, 
   3.861633700547532*^9, 3.861633963522799*^9, 3.861634028070588*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"9f8c14fc-76fa-49be-a4ec-e6daf5c2b5e9"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1280, 701},
WindowMargins->{{1, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 154, 3, 97, "Title",ExpressionUUID->"c7713ff5-e9bb-4841-bfb3-71a9575d1fb4"],
Cell[737, 27, 176, 3, 40, "Author",ExpressionUUID->"2724983a-4dd7-4b30-8959-193de7f6cacf"],
Cell[916, 32, 177, 3, 42, "Date",ExpressionUUID->"64e24950-607f-4fc5-951a-860858ef15e1"],
Cell[1096, 37, 6048, 162, 333, "Text",ExpressionUUID->"8100a627-7e1b-4469-8899-c97cce37d2ef"],
Cell[CellGroupData[{
Cell[7169, 203, 156, 3, 69, "Section",ExpressionUUID->"44bfb5d4-d821-464b-a599-42b2aa85d303"],
Cell[7328, 208, 1367, 33, 105, "Input",ExpressionUUID->"f9ff8b4e-7ff9-4ddc-b3e9-a27e4deddba9"],
Cell[8698, 243, 505, 12, 63, "Input",ExpressionUUID->"1a999f19-1447-4281-9b20-b87595d5b8d8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9240, 260, 152, 3, 69, "Section",ExpressionUUID->"f246066c-4a29-415a-8dbd-e13c58e61af9"],
Cell[CellGroupData[{
Cell[9417, 267, 1747, 41, 84, "Input",ExpressionUUID->"eeac07c1-d90f-4bed-be13-76943f425a92"],
Cell[11167, 310, 104837, 1756, 403, "Output",ExpressionUUID->"423b9d1c-dadf-477a-a2de-7b64150e29d8"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[116053, 2072, 171, 3, 69, "Section",ExpressionUUID->"12e73c43-bb13-4fbe-9fbc-97cb075b0d0d"],
Cell[116227, 2077, 2076, 51, 224, "Input",ExpressionUUID->"a4fca465-32e7-4bf1-9e7f-4e24847d2ac5"],
Cell[CellGroupData[{
Cell[118328, 2132, 1340, 36, 84, "Input",ExpressionUUID->"f62f42a1-51c9-4321-b592-25d0387766b4"],
Cell[119671, 2170, 802, 15, 313, "Output",ExpressionUUID->"b17ffd02-3181-4608-bcd1-da6c6a41a058"],
Cell[120476, 2187, 801, 15, 456, "Output",ExpressionUUID->"a2858f77-15ce-4740-967b-780f752145a7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[121314, 2207, 950, 18, 63, "Input",ExpressionUUID->"33b37129-4258-4463-87ba-1b209293418f"],
Cell[122267, 2227, 105347, 1766, 368, "Output",ExpressionUUID->"c54bd5cd-11b9-4d8e-836d-507245568a40"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[227663, 3999, 171, 3, 69, "Section",ExpressionUUID->"975c8d97-dba0-46b3-8f44-d444d875f7b3"],
Cell[227837, 4004, 1614, 38, 145, "Input",ExpressionUUID->"d9b7068a-61aa-48d6-8d82-c6780559f3ea"],
Cell[CellGroupData[{
Cell[229476, 4046, 1382, 30, 63, "Input",ExpressionUUID->"de29bbb0-7d6e-47a0-b289-784398a7dc5f"],
Cell[230861, 4078, 5531, 104, 407, "Output",ExpressionUUID->"933d8f39-4c7c-45ae-9707-395b6cc3cde0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[236441, 4188, 174, 3, 69, "Section",ExpressionUUID->"c98efa5d-ff9d-49e3-ac68-2076ea961c2b"],
Cell[CellGroupData[{
Cell[236640, 4195, 806, 16, 63, "Input",ExpressionUUID->"412efb08-62e7-419f-9924-418eaa5f98d9"],
Cell[237449, 4213, 109306, 1834, 341, "Output",ExpressionUUID->"9f8c14fc-76fa-49be-a4ec-e6daf5c2b5e9"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

